@@ -900,12 +900,11 @@ if (l == 5)
 *c /= sqrt (4.0 * GAMGI_MATH_PI);
 }
 
-static double static_density (double r, double value, gamgi_angular function_a)
+static double static_density (double r, double f, gamgi_angular function_a)
 {
-double theta, phi;
+double theta, phi, end;
 double x, y, z, s;
-double end;
-double f;
+double g;
 
 end = GAMGI_MATH_PI / 2.0;
 for (theta = 0.0; theta < end; theta += GAMGI_CHEM_ORBITAL_T_STEP)
@@ -918,8 +917,8 @@ for (theta = 0.0; theta < end; theta += GAMGI_CHEM_ORBITAL_T_STEP)
     x = s * cos (phi);
     y = s * sin (phi);
 
-    f = (*function_a) (x, y, z, r);
-    if (value * f * f > GAMGI_CHEM_ORBITAL_DENSITY) return TRUE;
+    g = f * (*function_a) (x, y, z, r);
+    if (g * g > GAMGI_CHEM_ORBITAL_DENSITY) return TRUE;
     }
   }
 
@@ -1023,7 +1022,7 @@ static_angular (orbital->l, orbital->m, &constant_a, &function_a);
 
 za = orbital->charge / GAMGI_CHEM_A0;
 ho = 2 * za / orbital->n;
-constant_z = pow (za, 1.5);
+constant_z = pow (za, 1.5) * pow (ho, orbital->l);
 constant = constant_z * constant_r * constant_a;
 
 /***************************************************
@@ -2516,7 +2515,7 @@ static_angular (orbital->l, orbital->m, &constant_a, &surface->function_a);
 
 za = orbital->charge / GAMGI_CHEM_A0;
 surface->ho = 2 * za / orbital->n;
-constant_z = pow (za, 1.5);
+constant_z = pow (za, 1.5) * pow (surface->ho, orbital->l);
 surface->constant = constant_z * constant_r * constant_a;
 
 /*****************************
@@ -2666,8 +2665,7 @@ static int static_solid (gamgi_orbital *orbital)
 {
 static_surface *surface;
 char *outside, *above;
-int slices, n_points;
-int a, b, c;
+int slices, a, b, c;
 
 /*****************
  * allocate data *
@@ -2682,7 +2680,6 @@ surface = static_start (orbital);
 outside = surface->outside;
 above = surface->above;
 slices = surface->slices;
-n_points = surface->n_points;
 
 for (c = 0; c <= 1; c++)
   {
@@ -2916,7 +2913,7 @@ if (m < -l || m > l) return 0.0;
 
 za = charge / GAMGI_CHEM_A0;
 ho = 2 * za / n;
-constant_z = pow (za, 1.5);
+constant_z = pow (za, 1.5) * pow (ho, l);
 
 static_radial (n, l, &constant_r, &function_r);
 static_angular (l, m, &constant_a, &function_a);
@@ -2932,7 +2929,7 @@ constant = constant_r * constant_z;
 for (r = 0.0; r < GAMGI_CHEM_ORBITAL_R_MAX; r += GAMGI_CHEM_ORBITAL_R_STEP)
   {
   rho = r * ho;
-  f = constant * exp (-rho / 2) * (*function_r) (rho);
+  f = constant * exp (-rho / 2) * pow (r, l) * (*function_r) (rho);
   d = f * f * r * r;
   if (d < d_old && d_old > d_old_old)
     r_max = r - GAMGI_CHEM_ORBITAL_R_STEP;
@@ -2957,7 +2954,7 @@ for (r = r_max; r < GAMGI_CHEM_ORBITAL_R_MAX; r += GAMGI_CHEM_ORBITAL_R_STEP)
   {
   rho = r * ho;
   f = constant * exp (-rho / 2) * (*function_r) (rho);
-  if (static_density (r, f * f, function_a) == FALSE) return r;
+  if (static_density (r, f, function_a) == FALSE) return r;
   }
 
 return GAMGI_CHEM_ORBITAL_R_MAX;
