@@ -349,10 +349,9 @@ gamgi_object object;
 void (*draw) (struct _gamgi_group *);
 int mark;
 
-gamgi_enum type;
+gamgi_enum reference;
 double origin[3], center[3];
 double quaternion[4];
-
 gamgi_bool faces;
 
 double *points;
@@ -412,11 +411,10 @@ typedef struct _gamgi_cluster {
 gamgi_object object;
 int mark;
 
-gamgi_enum type;
-gamgi_bool faces;
-
+gamgi_enum reference;
 double origin[3], center[3];
 double quaternion[4];
+gamgi_bool faces;
 
 double *points;
 int *loops;
@@ -425,7 +423,7 @@ int *paints;
 
 int n_points, n_loops;
 int n_colors, n_paints;
-int n_dots;
+int atoms;
 
 gamgi_dlist *text_start;
 gamgi_dlist *text_end;
