@@ -63,6 +63,13 @@ while (object->class < GAMGI_ENGINE_LAYER)
 return GAMGI_CAST_LAYER object;
 }
 
+gamgi_window *gamgi_engine_find_window (gamgi_object *object)
+{
+gamgi_layer *layer = gamgi_engine_find_layer (object);
+
+return GAMGI_CAST_WINDOW layer->object.object;
+}
+
 gamgi_object *gamgi_engine_find_root (gamgi_object *object1,
 gamgi_object *object2, gamgi_object *scope)
 {
