@@ -114,6 +114,13 @@ while (dlist != NULL)
   { gamgi_engine_remove_text (GAMGI_CAST_TEXT dlist->data);
     dlist = gamgi_engine_dlist_remove_start (dlist); }
 
+/*********************
+ * free array memory *
+ *********************/
+
+free (orbital->points);
+free (orbital->lines);
+
 /******************
  * remove orbital *
  ******************/
