@@ -12,6 +12,7 @@
 #include "gamgi_engine.h"
 #include "gamgi_mesa.h"
 #include "gamgi_chem.h"
+#include "gamgi_phys.h"
 #include "gamgi_global.h"
 
 #include "gamgi_engine_number.h"
@@ -343,7 +344,7 @@ group->object.number = gamgi_engine_number_group_get ();
  ********************/
 
 group->draw = NULL;
-group->type = FALSE;
+group->reference = FALSE;
 group->mark = 0;
 
 group->origin[0] = 0.0;
@@ -426,7 +427,7 @@ cluster->object.number = gamgi_engine_number_cluster_get ();
  * initialise cluster *
  **********************/
 
-cluster->type = FALSE;
+cluster->reference = FALSE;
 cluster->mark = 0;
 
 cluster->origin[0] = 0.0;
@@ -451,7 +452,7 @@ cluster->n_points = 0;
 cluster->n_loops = 0;
 cluster->n_colors = 0;
 cluster->n_paints = 0;
-cluster->n_dots = 0;
+cluster->atoms = 0;
 
 cluster->faces = FALSE;
 }
@@ -530,7 +531,7 @@ cell->axes_vectors = FALSE;
 
 cell->faces = FALSE;
 cell->nodes = FALSE;
-cell->borders = FALSE;
+cell->borders = GAMGI_PHYS_NONE;
 }
 
 /***** external function *****
