@@ -1059,7 +1059,7 @@ while (dlist != NULL)
  * write cdata: each point has 3 coordinates x,y,z *
  ***************************************************/
 
-if (group->type == GAMGI_CHEM_POLYTOPE)
+if (group->reference == GAMGI_CHEM_POLYTOPE)
   {
   static_cdata ("points", "double", 3 * group->n_points,
   group->points, window, fp, depth, depth_last, error);
@@ -1288,7 +1288,7 @@ while (dlist != NULL)
  * x,y,z and each color has 3 components r,g,b *
  ***********************************************/
 
-if (cluster->type == GAMGI_CHEM_POLYTOPE)
+if (cluster->reference == GAMGI_CHEM_POLYTOPE)
   {
   if (cluster->points != NULL)
     static_cdata ("points", "double", 3 * cluster->n_points,
