@@ -14,6 +14,7 @@
 #include "gamgi_mesa.h"
 #include "gamgi_math.h"
 #include "gamgi_chem.h"
+#include "gamgi_phys.h"
 #include "gamgi_expat.h"
 #include "gamgi_io.h"
 #include "gamgi_global.h"
@@ -423,10 +424,11 @@ int element, double mass, double radius, float red, float green, float blue)
 gamgi_atom_class *atom_class = gamgi->atom;
 char string_element[GAMGI_ENGINE_STRING];
 char string_attribute[GAMGI_ENGINE_STRING];
+char token[GAMGI_ENGINE_TOKEN];
 int column;
 
-gamgi_chem_atom_name (element, string_attribute);
-sprintf (string_element, "<atom element=\"%s\"", string_attribute);
+gamgi_chem_atom_name (element, token);
+sprintf (string_element, "<atom element=\"%s\"", token);
 
 if (fabs (atom_class->mass[element] - mass) > GAMGI_MATH_TOLERANCE)
   {
@@ -549,6 +551,135 @@ int depth_parent, int *depth_last, gamgi_bool *output, gamgi_bool *error)
 void gamgi_expat_export_config_cell (gamgi_window *window, FILE *fp,
 int depth_parent, int *depth_last, gamgi_bool *output, gamgi_bool *error)
 {
+gamgi_cell_class *cell_class = gamgi->cell;
+char string[GAMGI_ENGINE_STRING];
+int column;
+
+/***************
+ * model, axes *
+ ***************/
+
+if (cell_class->model != GAMGI_PHYS_CELL_MODEL)
+  {
+  if (cell_class->model == GAMGI_PHYS_CONVENTIONAL)
+    sprintf (string, "model=\"conventional\"");
+  else if (cell_class->model == GAMGI_PHYS_PRIMITIVE)
+    sprintf (string, "model=\"primitive\"");
+  else if (cell_class->model == GAMGI_PHYS_WIGNER)
+    sprintf (string, "model=\"wigner\"");
+  else if (cell_class->model == GAMGI_PHYS_PARALLELEPIPED)
+    sprintf (string, "model=\"parallelepiped\"");
+  else if (cell_class->model == GAMGI_PHYS_SPHERE)
+    sprintf (string, "model=\"sphere\"");
+  else if (cell_class->model == GAMGI_PHYS_PROJECTION)
+    sprintf (string, "model=\"projection\"");
+
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
+if (cell_class->axes != GAMGI_PHYS_CELL_AXES)
+  {
+  if (cell_class->axes == TRUE)
+    sprintf (string, "axes=\"yes\"");
+  else
+    sprintf (string, "axes=\"no\"");
+
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
+/*************************
+ * borders, faces, nodes *
+ *************************/
+
+if (cell_class->borders != GAMGI_PHYS_CELL_BORDERS)
+  {
+  if (cell_class->borders == GAMGI_PHYS_ALL)
+    sprintf (string, "borders=\"all\"");
+  else if (cell_class->borders == GAMGI_PHYS_FACES)
+    sprintf (string, "borders=\"faces\"");
+  else if (cell_class->borders == GAMGI_PHYS_EDGES)
+    sprintf (string, "borders=\"edges\"");
+  else if (cell_class->borders == GAMGI_PHYS_NONE)
+    sprintf (string, "borders=\"none\"");
+
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
+if (cell_class->faces != GAMGI_PHYS_CELL_FACES)
+  {
+  if (cell_class->faces == TRUE)
+    sprintf (string, "faces=\"yes\"");
+  else
+    sprintf (string, "faces=\"no\"");
+
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
+if (cell_class->nodes != GAMGI_PHYS_CELL_NODES)
+  {
+  if (cell_class->nodes == TRUE)
+    sprintf (string, "nodes=\"yes\"");
+  else
+    sprintf (string, "nodes=\"no\"");
+
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
+/****************************
+ * red,green,blue (coupled) *
+ ****************************/
+
+if (fabs (cell_class->red - GAMGI_MESA_CELL_R) > GAMGI_MATH_TOLERANCE
+|| fabs (cell_class->green - GAMGI_MESA_CELL_G) > GAMGI_MATH_TOLERANCE
+|| fabs (cell_class->blue - GAMGI_MESA_CELL_B) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "red=\"%.*f\"",
+  GAMGI_MATH_DECIMAL_COLOR, cell_class->red);
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+
+  sprintf (string, "green=\"%.*f\"",
+  GAMGI_MATH_DECIMAL_COLOR, cell_class->green);
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+
+  sprintf (string, "blue=\"%.*f\"",
+  GAMGI_MATH_DECIMAL_COLOR, cell_class->blue);
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
+/************************************************************
+ * Global parameters: axes sise, borders width, nodes width *
+ ************************************************************/
+
+if (fabs (cell_class->axes_size - GAMGI_MESA_AXES_SIZE) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "axes_size=\"%.*f\"",
+  GAMGI_MATH_DECIMAL_SIZE, cell_class->axes_size);
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
+if (cell_class->borders_width != GAMGI_MESA_CELL_LINE)
+  {
+  sprintf (string, "borders_width=\"%d\"", cell_class->borders_width);
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
+if (cell_class->nodes_width != GAMGI_MESA_CELL_POINT)
+  {
+  sprintf (string, "nodes_width=\"%d\"", cell_class->nodes_width);
+  gamgi_expat_export_element (fp, "<cell", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
 }
 
 void gamgi_expat_export_config_arrow (gamgi_window *window, FILE *fp,
