@@ -336,12 +336,12 @@ if (strcmp (token, "11111111") != 0)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-if (orbital->axes == GAMGI_CHEM_UNIT)
+if (orbital->axes == GAMGI_CHEM_RADIUS)
+  gamgi_expat_export_attribute (fp, "axes=\"radius\"", depth, column, error);
+else if (orbital->axes == GAMGI_CHEM_UNIT)
   gamgi_expat_export_attribute (fp, "axes=\"unit\"", depth, column, error);
 else if (orbital->axes == GAMGI_CHEM_BOHR)
   gamgi_expat_export_attribute (fp, "axes=\"bohr\"", depth, column, error);
-else if (orbital->axes == GAMGI_CHEM_RADIUS)
-  gamgi_expat_export_attribute (fp, "axes=\"radius\"", depth, column, error);
 
 /*************************************
  * origin: x,y,z (optional, coupled) *
@@ -1207,12 +1207,12 @@ if (GAMGI_EXPAT_ID_GROUP == TRUE)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-/*************
- * Type page *
- *************/
+/******************
+ * Reference page *
+ ******************/
 
-if (group->type == GAMGI_CHEM_POLYTOPE)
-  gamgi_expat_export_attribute (fp, "type=\"polytope\"", depth, column, error);
+if (group->reference == GAMGI_CHEM_POLYTOPE)
+  gamgi_expat_export_attribute (fp, "reference=\"polytope\"", depth, column, error);
 
 /*****************
  * Position page *
@@ -1373,12 +1373,12 @@ if (GAMGI_EXPAT_ID_CLUSTER == TRUE)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-/*************
- * Type page *
- *************/
+/******************
+ * Reference page *
+ ******************/
 
-if (cluster->type == GAMGI_CHEM_POLYTOPE)
-  gamgi_expat_export_attribute (fp, "type=\"polytope\"", depth, column, error);
+if (cluster->reference == GAMGI_CHEM_POLYTOPE)
+  gamgi_expat_export_attribute (fp, "reference=\"polytope\"", depth, column, error);
 
 /*****************
  * Position data *
@@ -1435,13 +1435,13 @@ if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-/*********************************
- * dots,faces,borders (optional) *
- *********************************/
+/**************************
+ * atoms,faces (optional) *
+ **************************/
 
-if (cluster->n_dots > 0)
+if (cluster->atoms > 0)
   {
-  sprintf (string, "dots=\"%d\"", cluster->n_dots);
+  sprintf (string, "atoms=\"%d\"", cluster->atoms);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
@@ -1566,49 +1566,15 @@ if (cell->reciprocal != 0.0)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-/*************************************
- * origin: x,y,z (optional, coupled) *
- *************************************/
-
-gamgi_math_position_cell_translation_get (cell, origin);
-
-if (fabs (origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
-|| fabs (origin[1] - 0.0) > GAMGI_MATH_TOLERANCE
-|| fabs (origin[2] - 0.0) > GAMGI_MATH_TOLERANCE)
-  {
-  sprintf (string, "x=\"%.*f\"", gamgi->gamgi->length, origin[0]);
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  sprintf (string, "y=\"%.*f\"", gamgi->gamgi->length, origin[1]);
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  sprintf (string, "z=\"%.*f\"", gamgi->gamgi->length, origin[2]);
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  }
-
-/**********************************************
- * Euler angles: e1,e2,e3 (optional, coupled) *
- **********************************************/
-
-gamgi_math_position_cell_rotation_get (cell, euler);
-
-if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
-|| fabs (euler[1] - 0.0) > GAMGI_MATH_TOLERANCE
-|| fabs (euler[2] - 0.0) > GAMGI_MATH_TOLERANCE)
-  {
-  sprintf (string, "e1=\"%.*f\"", gamgi->gamgi->angle, euler[0]);
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  sprintf (string, "e2=\"%.*f\"", gamgi->gamgi->angle, euler[1]);
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  sprintf (string, "e3=\"%.*f\"", gamgi->gamgi->angle, euler[2]);
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  }
-
 /*********************
  * volume (optional) *
  *********************/
 
-if (cell->model != GAMGI_PHYS_CONVENTIONAL)
+if (cell->model != gamgi->cell->model)
   {
-  if (cell->model == GAMGI_PHYS_PRIMITIVE)
+  if (cell->model == GAMGI_PHYS_CONVENTIONAL)
+    sprintf (string, "model=\"%s\"", "conventional");
+  else if (cell->model == GAMGI_PHYS_PRIMITIVE)
     sprintf (string, "model=\"%s\"", "primitive");
   else if (cell->model == GAMGI_PHYS_WIGNER)
     sprintf (string, "model=\"%s\"", "wigner");
@@ -1667,25 +1633,41 @@ if (cell->model == GAMGI_PHYS_PARALLELEPIPED)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-/**********************************
- * nodes,faces,borders (optional) *
- **********************************/
+/*************************************
+ * origin: x,y,z (optional, coupled) *
+ *************************************/
 
-if (cell->nodes == FALSE && cell->model != GAMGI_PHYS_PROJECTION)
-  gamgi_expat_export_attribute (fp, "nodes=\"no\"", depth, column, error);
+gamgi_math_position_cell_translation_get (cell, origin);
 
-if (cell->faces == TRUE) 
-  gamgi_expat_export_attribute (fp, "faces=\"yes\"", depth, column, error);
+if (fabs (origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (origin[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (origin[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "x=\"%.*f\"", gamgi->gamgi->length, origin[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "y=\"%.*f\"", gamgi->gamgi->length, origin[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "z=\"%.*f\"", gamgi->gamgi->length, origin[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
 
-if (cell->borders == FALSE)
-  gamgi_expat_export_attribute (fp, "borders=\"none\"", depth, column, error);
+/**********************************************
+ * Euler angles: e1,e2,e3 (optional, coupled) *
+ **********************************************/
 
-else if (cell->borders == GAMGI_PHYS_EDGES && cell->model != GAMGI_PHYS_PARALLELEPIPED
-&& cell->model != GAMGI_PHYS_SPHERE && cell->model != GAMGI_PHYS_PROJECTION)
-  gamgi_expat_export_attribute (fp, "borders=\"edges\"", depth, column, error);
+gamgi_math_position_cell_rotation_get (cell, euler);
 
-else if (cell->borders == GAMGI_PHYS_FACES && cell->faces == FALSE)
-  gamgi_expat_export_attribute (fp, "borders=\"faces\"", depth, column, error);
+if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (euler[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (euler[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "e1=\"%.*f\"", gamgi->gamgi->angle, euler[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "e2=\"%.*f\"", gamgi->gamgi->angle, euler[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "e3=\"%.*f\"", gamgi->gamgi->angle, euler[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
 
 /*********************************
  * o1,o2,o3, (optional, coupled) *
@@ -1719,36 +1701,87 @@ if (o4 != FALSE)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
+/*********************************************************
+ * by default, vectors are conventional for conventional *
+ * parallelepiped, sphere and projection cells, and      *
+ * primitive for primitive and wigner-seitz cells        *
+ *********************************************************/
+
 if (o4 == FALSE && (o1 != 0 || o2 != 0 || 03 != 0))
   {
-  if (cell->origin_vectors != GAMGI_PHYS_CELL_VECTORS_ORIGIN)
-    {
-    if (cell->origin_vectors == GAMGI_PHYS_CONVENTIONAL)
-      sprintf (string, "origin_vectors=\"conventional\"");
-    if (cell->origin_vectors == GAMGI_PHYS_PRIMITIVE)
-      sprintf (string, "origin_vectors=\"primitive\"");
-    gamgi_expat_export_attribute (fp, string, depth, column, error);
-    }
+  if (cell->origin_vectors == GAMGI_PHYS_PRIMITIVE &&
+  (cell->model != GAMGI_PHYS_PRIMITIVE && cell->model != GAMGI_PHYS_WIGNER))
+    gamgi_expat_export_attribute (fp,
+    "origin_vectors=\"primitive\"", depth, column, error);
+
+  if (cell->origin_vectors == GAMGI_PHYS_CONVENTIONAL &&
+  (cell->model == GAMGI_PHYS_PRIMITIVE || cell->model == GAMGI_PHYS_WIGNER))
+    gamgi_expat_export_attribute (fp,
+    "origin_vectors=\"conventional\"", depth, column, error);
   }
 
 /*********************************
  * axes, axes_vectors (optional) *
  *********************************/
 
+if (cell->axes != gamgi->cell->axes)
+  {
+  if (cell->axes == TRUE)
+    gamgi_expat_export_attribute (fp, "axes=\"yes\"", depth, column, error);
+  else
+    gamgi_expat_export_attribute (fp, "axes=\"no\"", depth, column, error);
+  }
+
+/*********************************************************
+ * by default, vectors are conventional for conventional *
+ * parallelepiped, sphere and projection cells, and      *
+ * primitive for primitive and wigner-seitz cells        *
+ *********************************************************/
+
 if (cell->axes == TRUE)
   {
-  sprintf (string, "axes=\"yes\"");
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  if (cell->axes_vectors == GAMGI_PHYS_PRIMITIVE &&
+  (cell->model != GAMGI_PHYS_PRIMITIVE && cell->model != GAMGI_PHYS_WIGNER))
+    gamgi_expat_export_attribute (fp,
+    "axes_vectors=\"primitive\"", depth, column, error);
 
-  if (cell->axes_vectors != GAMGI_PHYS_CELL_VECTORS_AXES)
-    {
-    if (cell->axes_vectors == GAMGI_PHYS_CONVENTIONAL)
-      sprintf (string, "axes_vectors=\"conventional\"");
-    if (cell->axes_vectors == GAMGI_PHYS_PRIMITIVE)
-      sprintf (string, "axes_vectors=\"primitive\"");
-    gamgi_expat_export_attribute (fp, string, depth, column, error);
-    }
+  if (cell->axes_vectors == GAMGI_PHYS_CONVENTIONAL &&
+  (cell->model == GAMGI_PHYS_PRIMITIVE || cell->model == GAMGI_PHYS_WIGNER))
+    gamgi_expat_export_attribute (fp,
+    "axes_vectors=\"conventional\"", depth, column, error);
+  }
 
+/**********************************
+ * borders,faces,nodes (optional) *
+ **********************************/
+
+if (cell->borders != gamgi->cell->borders && cell->model != GAMGI_PHYS_PROJECTION)
+  {
+  if (cell->borders == GAMGI_PHYS_ALL)
+    gamgi_expat_export_attribute (fp, "borders=\"all\"", depth, column, error);
+  else if (cell->borders == GAMGI_PHYS_FACES)
+    gamgi_expat_export_attribute (fp, "borders=\"faces\"", depth, column, error);
+  else if (cell->borders == GAMGI_PHYS_EDGES)
+    gamgi_expat_export_attribute (fp, "borders=\"edges\"", depth, column, error);
+  else if (cell->borders == GAMGI_PHYS_NONE)
+    gamgi_expat_export_attribute (fp, "borders=\"none\"", depth, column, error);
+  }
+
+if (cell->faces != gamgi->cell->faces && cell->model != GAMGI_PHYS_PROJECTION
+&& cell->model != GAMGI_PHYS_PARALLELEPIPED && cell->model != GAMGI_PHYS_SPHERE)
+  {
+  if (cell->faces == TRUE)
+    gamgi_expat_export_attribute (fp, "faces=\"yes\"", depth, column, error);
+  else
+    gamgi_expat_export_attribute (fp, "faces=\"no\"", depth, column, error);
+  }
+
+if (cell->nodes != gamgi->cell->nodes && cell->model != GAMGI_PHYS_PROJECTION)
+  {
+  if (cell->nodes == TRUE)
+    gamgi_expat_export_attribute (fp, "nodes=\"yes\"", depth, column, error);
+  else
+    gamgi_expat_export_attribute (fp, "nodes=\"no\"", depth, column, error);
   }
 
 /**************************************
@@ -2240,16 +2273,6 @@ if (fabs (layer->color[0] - GAMGI_MESA_LAYER_R) > GAMGI_MATH_TOLERANCE
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-/*******************
- * axes (optional) *
- *******************/
-
-if (layer->axes == TRUE)
-  {
-  sprintf (string, "axes=\"yes\"");
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  }
-
 /********************
  * scale (optional) *
  ********************/
