@@ -24,6 +24,7 @@
 #include "gamgi_gtk_history.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_mesa_translate.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_chem_atom.h"
 #include "gamgi_chem_bond.h"
 #include "gamgi_math_vector.h"
@@ -432,23 +433,6 @@ if (child->object == parent)
   return FALSE;
   }
 
-/*******************************************************************
- * some objects, such as planes and directions, might depend       *
- * entirely on their parents (crystallographic planes,directions), *
- * or have a life of their own (atomic planes,directions). Only    *
- * the second can be linked to other parents (not necessarily in   *
- * the same layer). Dependent objects can be linked, however,      *
- * to all possible child objects, without any restrictions.        *
- *******************************************************************/
-
-if (gamgi_gtk_object_independence (child) == FALSE)
-  {
-  if (cache.local == TRUE)
-    gamgi_gtk_dialog_message_create ("Error",
-    "Child is not an independent object", window);
-  return FALSE;
-  }
-
 /**********************************************
  * save layers before linking child to parent *
  **********************************************/
@@ -493,15 +477,7 @@ else
 
   if (layer_parent != layer_child) gamgi_chem_bond_half_remove (child);
 
-  /***************************************************************
-   * if atom is defining an atomic plane,direction then reparent *
-   *  plane,direction child objects and remove plane,direction   *
-   ***************************************************************/
-
-  if (child->class == GAMGI_ENGINE_ATOM)
-    gamgi_chem_atom_unlink (GAMGI_CAST_ATOM child);
-  else
-    gamgi_engine_unlink_object (child);
+  gamgi_engine_unlink_object (child);
   }
 
 gamgi_engine_link_object_object (child, parent);
@@ -550,10 +526,10 @@ gamgi_global_selection_focus ();
 
 if (cache.above == TRUE)
   {
-  /********************************
-   * link each listed assembly to *
-   * the parent selected object   *
-   ********************************/
+  /*******************************************
+   * link above: link each listed assembly   *
+   * (child) to the selected object (parent) *
+   *******************************************/
 
   parent = cache.object;
   layer_parent = gamgi_engine_find_layer (parent);
@@ -579,13 +555,12 @@ if (cache.above == TRUE)
   window_parent = GAMGI_CAST_WINDOW layer_parent->object.object;
   gamgi_gtk_object_raise (layer_parent, window_parent);
   } 
-
-if (cache.above == FALSE)
+else
   {
-  /******************************************
-   * link each listed assembly to a child   *
-   * object copied from the selected object *
-   ******************************************/
+  /*****************************************************
+   * link below: link each listed assembly (parent) to *
+   * a child object copied from the selected object    *
+   *****************************************************/
 
   child = cache.object;
 
@@ -607,7 +582,7 @@ if (cache.above == FALSE)
 
 gamgi_io_error_list (start, window_dialog);
 
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 
 /****************
  * reset dialog *
@@ -641,6 +616,11 @@ if (assembly == NULL)
 
 if (static_grab (window_dialog) == FALSE) return;
 
+/**************************************************************************
+ * link above: link selected assembly (child) to selected object (parent) *
+ * link below: link selected assembly (parent) to selected object (child) *
+ **************************************************************************/
+
 if (cache.above == TRUE)
   { child = GAMGI_CAST_OBJECT assembly; parent = cache.object; }
 else
@@ -780,6 +760,7 @@ GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
 GtkWidget *entry;
+gamgi_bool global;
 const char *name;
 
 /***********************************************
@@ -791,17 +772,24 @@ button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_assembly");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
+/***********************************************
+ * global selection can be used only to select *
+ * the second object, not the main object      *
+ ***********************************************/
+
+global = TRUE;
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE &&
-gamgi_io_token_check (name) == FALSE && 
-window_dialog != window_mouse) return;
+gamgi_io_token_check (name) == FALSE) global = FALSE;
 
 /************************************************************************
  * window_dialog is the (local) window where the dialog window was open *
  * window_mouse is the (global) window where the user presses the mouse *
  ************************************************************************/
 
+if (global == FALSE && window_dialog != window_mouse) return;
+
 gamgi_mesa_select_object (window_mouse, x, y,
-static_class (window_dialog), TRUE, static_press);
+static_class (window_dialog), global, static_press);
 }
 
 /********************** external function ***************
