@@ -289,9 +289,9 @@ int row;
 
 atom_class = gamgi_global_copy_atom (gamgi->atom);
 
-/*******************************************************************
- * get element,mass,radius,red,green,blue local element parameters *
- *******************************************************************/
+/**********************************************************************
+ * get Element default parameters: element,mass,radius,red,green,blue *
+ **********************************************************************/
 
 /***********
  * element *
@@ -336,85 +336,7 @@ GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   return;
   }
 
-/***************
- * temperature *
- ***************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_temperature");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &atom_class->temperature, 0.0, DBL_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid temperature", window);
-  gamgi_global_remove_atom (atom_class);
-  return;
-  }
-
-/*************************
- * style, size, variancy *
- *************************/
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (row == GAMGI_MESA_WIRED - 1) atom_class->draw = gamgi_mesa_atom_draw_cross;
-if (row == GAMGI_MESA_SOLID - 1) atom_class->draw = gamgi_mesa_atom_draw_sphere;
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
-entry = gtk_bin_get_child (GTK_BIN (combo));
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_float_scan (name, &atom_class->size,
-GAMGI_MATH_TOLERANCE, FLT_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid size", window);
-  gamgi_global_remove_atom (atom_class);
-  return;
-  }
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_variancy");
-entry = gtk_bin_get_child (GTK_BIN (combo));
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_float_scan (name, &atom_class->variancy,
-0.0, FLT_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid variancy", window);
-  gamgi_global_remove_atom (atom_class);
-  return;
-  }
-
-/**************************************
- * slices, minimum radius, line width *
- **************************************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_slices");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &atom_class->slices,
-GAMGI_MESA_ATOM_SLICES_MIN, GAMGI_MESA_ATOM_SLICES_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid slices", window);
-  gamgi_global_remove_atom (atom_class);
-  return;
-  }
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_min");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &atom_class->min, 
-GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid minimum radius", window);
-  gamgi_global_remove_atom (atom_class);
-  return;
-  }
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_width");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &atom_class->width,
-GAMGI_MESA_ATOM_WIDTH_MIN, GAMGI_MESA_ATOM_WIDTH_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid line width", window);
-  gamgi_global_remove_atom (atom_class);
-  return;
-  }
-
-/******************
+ /******************
  * red,green,blue *
  ******************/
 
@@ -456,6 +378,84 @@ if (gamgi_io_token_check (name) == TRUE)
     return;
     }
   }
+ 
+/************************************************
+ * get Analysis default parameters: temperature *
+ ************************************************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_temperature");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &atom_class->temperature, 0.0, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid temperature", window);
+  gamgi_global_remove_atom (atom_class);
+  return;
+  }
+
+/********************************************************
+ * get View default parameters: style,size,variancy,min *
+ ********************************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == GAMGI_MESA_WIRED - 1) atom_class->draw = gamgi_mesa_atom_draw_cross;
+if (row == GAMGI_MESA_SOLID - 1) atom_class->draw = gamgi_mesa_atom_draw_sphere;
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
+entry = gtk_bin_get_child (GTK_BIN (combo));
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_float_scan (name, &atom_class->size,
+GAMGI_MATH_TOLERANCE, FLT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid size", window);
+  gamgi_global_remove_atom (atom_class);
+  return;
+  }
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_variancy");
+entry = gtk_bin_get_child (GTK_BIN (combo));
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_float_scan (name, &atom_class->variancy,
+0.0, FLT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid variancy", window);
+  gamgi_global_remove_atom (atom_class);
+  return;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_min");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &atom_class->min,
+GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid minimum radius", window);
+  gamgi_global_remove_atom (atom_class);
+  return;
+  }
+
+/******************************************************************************
+ * get Global parameters: slices (for solid spheres), width (for wired lines) *
+ ******************************************************************************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_slices");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_int_scan (name, &atom_class->slices,
+GAMGI_MESA_ATOM_SLICES_MIN, GAMGI_MESA_ATOM_SLICES_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid slices", window);
+  gamgi_global_remove_atom (atom_class);
+  return;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_width");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_int_scan (name, &atom_class->width,
+GAMGI_MESA_ATOM_WIDTH_MIN, GAMGI_MESA_ATOM_WIDTH_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid line width", window);
+  gamgi_global_remove_atom (atom_class);
+  return;
+  }
 
 /*************************************************************
  * red,green,blue are coupled parameters: define all or none *
@@ -490,10 +490,9 @@ if (element != -1 && (mass == -1.0 && radius == -1.0 && color == 0))
   return;
   }
 
-/*************************************
- * set element properties: first we  *
- * must ensure that element is valid *
- *************************************/
+/************************************************
+ * set element properties, after validity tests *
+ ************************************************/
 
 if (mass != -1.0) atom_class->mass[element] = mass;
 if (radius != -1.0) atom_class->radius[element] = radius;
@@ -767,6 +766,55 @@ G_CALLBACK (gamgi_gtk_atom_property_radius), window);
 g_object_set_data (G_OBJECT (dialog), "button_radius", button);
 gtk_widget_show (button);
 
+/*********
+ * color *
+ *********/
+
+hbox_center = gtk_hbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
+table = gtk_table_new (1, 7, FALSE);
+gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
+gtk_widget_show (table);
+
+label = gtk_label_new ("Color");
+gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+gtk_widget_show (label);
+
+label = gtk_label_new ("R");
+gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+gtk_widget_show (label);
+
+label = gtk_label_new ("G");
+gtk_table_attach (GTK_TABLE (table), label, 4, 5, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+gtk_widget_show (label);
+
+label = gtk_label_new ("B");
+gtk_table_attach (GTK_TABLE (table), label, 6, 7, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_object_set_data (G_OBJECT (dialog), "entry_red", entry);
+gtk_widget_show (entry);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 3, 4, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_object_set_data (G_OBJECT (dialog), "entry_green", entry);
+gtk_widget_show (entry);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 5, 6, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_object_set_data (G_OBJECT (dialog), "entry_blue", entry);
+gtk_widget_show (entry);
+ 
 /*****************
  * Analysis page *
  *****************/
@@ -818,36 +866,28 @@ vbox_center = gtk_vbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
 gtk_widget_show (vbox_center);
 
-vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
-gtk_widget_show (vbox_top);
-
-/********************
- * style, size, min *
- ********************/
-
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
+/***************
+ * left column *
+ ***************/
+
+vbox_top = gtk_vbox_new (TRUE, 15);
+gtk_box_pack_start (GTK_BOX (hbox_center), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
 
 /*********
  * style *
  *********/
 
-hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left_left);
-
-label = gtk_label_new ("Style");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
-gtk_widget_show (label);
+hbox_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
 
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
+gtk_box_pack_end (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
 g_object_set_data (G_OBJECT (dialog), "combo_style", combo);
 gtk_widget_show (combo);
 
@@ -863,21 +903,61 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
+label = gtk_label_new ("Style");
+gtk_box_pack_end (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+/************
+ * variancy *
+ ************/
+
+hbox_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
+
+combo = gtk_combo_box_entry_new ();
+gtk_box_pack_end (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_object_set_data (G_OBJECT (dialog), "combo_variancy", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 0.0);
+gtk_list_store_set (store, &iter, 0, token, -1);
+gtk_list_store_append (store, &iter);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 1.0);
+gtk_list_store_set (store, &iter, 0, token, -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
+
+label = gtk_label_new ("Variancy");
+gtk_box_pack_end (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "label_variancy", label);
+gtk_widget_show (label);
+
+/****************
+ * right column *
+ ****************/
+
+vbox_top = gtk_vbox_new (TRUE, 15);
+gtk_box_pack_start (GTK_BOX (hbox_center), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
+
 /********
  * size *
  ********/
 
-hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left_left);
-
-label = gtk_label_new ("Size");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_size", label);
-gtk_widget_show (label);
+hbox_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
 
 combo = gtk_combo_box_entry_new ();
-gtk_box_pack_end (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
+gtk_box_pack_end (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
 entry = gtk_bin_get_child (GTK_BIN (combo));
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
@@ -899,25 +979,48 @@ g_object_unref (store);
 
 gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
 
-/***********************************
- *  minimum radius (H, by default) *
- ***********************************/
-
-hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left_left);
-
-label = gtk_label_new ("Min");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+label = gtk_label_new ("Size");
+gtk_box_pack_end (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "label_size", label);
 gtk_widget_show (label);
 
+/**********************************
+ * minimum radius (H, by default) *
+ **********************************/
+
+hbox_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
+
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
+gtk_box_pack_end (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_min", entry);
 gtk_widget_show (entry);
 
+label = gtk_label_new ("Min");
+gtk_box_pack_end (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+/***************
+ * Global page *
+ ***************/
+
+vbox_page = gtk_vbox_new (FALSE, 5);
+label = gtk_label_new ("Global");
+gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
+gtk_widget_show (vbox_page);
+
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
+
+vbox_top = gtk_vbox_new (FALSE, 10);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
+
 /***************************
  * variancy, slices, width *
  ***************************/
@@ -930,39 +1033,6 @@ hbox_left = gtk_hbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-/************
- * variancy *
- ************/
-
-hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left_left);
-
-label = gtk_label_new ("Variancy");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_variancy", label);
-gtk_widget_show (label);
-
-combo = gtk_combo_box_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
-entry = gtk_bin_get_child (GTK_BIN (combo));
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-g_object_set_data (G_OBJECT (dialog), "combo_variancy", combo);
-gtk_widget_show (combo);
-
-store = gtk_list_store_new (1, G_TYPE_STRING);
-gtk_list_store_append (store, &iter);
-sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 0.0);
-gtk_list_store_set (store, &iter, 0, token, -1);
-gtk_list_store_append (store, &iter);
-sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 1.0);
-gtk_list_store_set (store, &iter, 0, token, -1);
-gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
-
 /******************************
  * spherical/cylindric Slices *
  ******************************/
@@ -1001,55 +1071,6 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_2);
 g_object_set_data (G_OBJECT (dialog), "entry_width", entry);
 gtk_widget_show (entry);
 
-/*********
- * color *
- *********/
-
-hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
-gtk_widget_show (hbox_center);
-
-table = gtk_table_new (1, 7, FALSE);
-gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
-gtk_widget_show (table);
-
-label = gtk_label_new ("Color");
-gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
-gtk_widget_show (label);
-
-label = gtk_label_new ("R");
-gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
-gtk_widget_show (label);
-
-label = gtk_label_new ("G");
-gtk_table_attach (GTK_TABLE (table), label, 4, 5, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
-gtk_widget_show (label);
-
-label = gtk_label_new ("B");
-gtk_table_attach (GTK_TABLE (table), label, 6, 7, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
-gtk_widget_show (label);
-
-entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-g_object_set_data (G_OBJECT (dialog), "entry_red", entry);
-gtk_widget_show (entry);
-
-entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 3, 4, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-g_object_set_data (G_OBJECT (dialog), "entry_green", entry);
-gtk_widget_show (entry);
-
-entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 5, 6, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-g_object_set_data (G_OBJECT (dialog), "entry_blue", entry);
-gtk_widget_show (entry);
-
 /*********************
  * Ok/Cancel buttons *
  *********************/
