@@ -487,7 +487,8 @@ if (gamgi_io_token_double_scan (name, &atom->charge, -DBL_MAX, DBL_MAX) == FALSE
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_temperature");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &atom->temperature, 0.0, DBL_MAX) == FALSE)
+if (gamgi_io_token_double_scan (name, &atom->temperature,
+GAMGI_CHEM_ATOM_TEMPERATURE_MIN, GAMGI_CHEM_ATOM_TEMPERATURE_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid temperature", window);
   gamgi_engine_remove_atom (atom);
@@ -700,7 +701,7 @@ if (atom_class->draw == gamgi_mesa_atom_draw_sphere)
  ************************************/
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_temperature");
-sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_TEMPERATURE, atom_class->temperature);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_OCCUPANCY, atom_class->temperature);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_occupancy");
