@@ -23,7 +23,7 @@ static void static_style (GtkWidget *widget, void *data);
 
 static void static_default (int number, char *name, gamgi_window *window);
 
-static void static_name (GtkWidget *widget, void *data);
+static void static_element (GtkWidget *widget, void *data);
 
 static void static_number (GtkWidget *widget, void *data);
 
@@ -45,7 +45,7 @@ static void static_init (gamgi_window *window);
  **********************/
 
 void gamgi_gtk_atom_create_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog);
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog);
 
 void gamgi_gtk_atom_create (GtkWidget *widget, void *data);
 
