@@ -15,7 +15,8 @@
 
 static void static_remove (GtkWidget *widget, void *data);
 
-static void static_delete (GtkWidget *widget, GdkEventButton *event, void *data);
+static int static_delete (GtkWidget *widget,
+GdkEventButton *event, void *data);
 
 static void static_mass_select (GtkWidget *widget, void *data);
 
@@ -23,7 +24,6 @@ static void static_radius_select (GtkWidget *widget, void *data);
 
 static void static_charge_select (GtkWidget *widget, void *data);
 
-
 static void static_mass_create (GtkWidget *widget, void *data);
 
 static void static_radius_create (GtkWidget *widget, void *data);
