@@ -20,7 +20,8 @@ int r, int g, int b, int x0, int  y0, int x1, int y1, gamgi_window *window);
 
 static void static_remove (GtkWidget *widget, void *data);
 
-static void static_delete (GtkWidget *widget, GdkEventButton *event, void *data);
+static int static_delete (GtkWidget *widget,
+GdkEventButton *event, void *data);
 
  **********************
  * external functions *
