@@ -678,7 +678,10 @@ if (bond_class->draw == gamgi_mesa_bond_draw_cylinder)
   gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_MESA_SOLID - 1);
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_color");
-gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
+if (bond_class->color == TRUE)
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+else
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
