@@ -27,7 +27,7 @@ static void static_vectors (GtkWidget *widget, void *data);
 
 static void static_faces (GtkWidget *widget, void *data);
 
-static void static_volume (GtkWidget *widget, void *data);
+static void static_model (GtkWidget *widget, void *data);
 
 static void static_button (GtkWidget *dialog, char *string);
 
