@@ -149,7 +149,7 @@ if (scope == 1)
     { 
     plane = GAMGI_CAST_PLANE dlist->data;
     dlist = dlist->next;
-    if (plane->type != GAMGI_PHYS_POLYGON)
+    if (plane->model != GAMGI_PHYS_POLYGON)
       { gamgi_engine_unlink_plane (plane);
         gamgi_engine_remove_plane (plane); }
     }
@@ -160,7 +160,7 @@ if (scope == 1)
     { 
     direction = GAMGI_CAST_DIRECTION dlist->data;
     dlist = dlist->next;
-    if (direction->type != GAMGI_PHYS_LINE)
+    if (direction->model != GAMGI_PHYS_LINE)
       { gamgi_engine_unlink_direction (direction);
         gamgi_engine_remove_direction (direction); }
     }
