@@ -56,7 +56,8 @@ static void static_select_group (GtkWidget *widget, void *data);
 
 static void static_remove (GtkWidget *widget, void *data);
 
-static void static_delete (GtkWidget *widget, GdkEventButton *event, void *data);
+static int static_delete (GtkWidget *widget,
+GdkEventButton *event, void *data);
 
 static void static_system (GtkWidget *widget, void *data);
 
