@@ -37,10 +37,16 @@ int hkl1[3], hkl2[3];
 int start1, end1;
 int start2, end2; } range;
 
-static void static_delete (GtkWidget *widget,
+static int static_delete (GtkWidget *widget,
 GdkEventButton *event, void *data)
 {
 gamgi_gtk_direction_range_cancel (widget, data);
+
+/*************************
+ * FALSE: destroy window *
+ *************************/
+
+return FALSE;
 }
 
 static void static_start (GtkWidget *widget, void *data)
