@@ -13,8 +13,8 @@
  * internal functions *
  **********************
 
-static void static_delete (GtkWidget *widget,
-GdkEventButton *event, void *data)
+static int static_delete (GtkWidget *widget,
+GdkEventButton *event, void *data);
 
 static void static_start (GtkWidget *widget, void *data);
 
