@@ -134,7 +134,7 @@ int length;
  * path < GAMGI_IO_PATHNAME, otherwise ignore excess *
  *****************************************************/
 
-strncpy (pathname, path, GAMGI_IO_PATHNAME - 1);
+gamgi_io_token_cut (path, pathname, GAMGI_IO_PATHNAME);
 length = strlen (pathname);
 
 /****************************************
@@ -169,7 +169,7 @@ if (directory != NULL)
      * path + child->d_name < GAMGI_IO_PATHNAME, otherwise ignore excess *
      *********************************************************************/
 
-    strncpy (pathname + length, child->d_name, GAMGI_IO_PATHNAME - length - 1);
+    gamgi_io_token_cut (child->d_name, pathname + length, GAMGI_IO_PATHNAME - length);
     if (static_dir (pathname) == TRUE)
       {
       if (static_hide_folders (child->d_name, window) == TRUE) continue;
@@ -227,7 +227,7 @@ int length;
  * path < GAMGI_IO_PATHNAME, otherwise ignore excess *
  *****************************************************/
 
-strncpy (fullname, path, GAMGI_IO_PATHNAME - 1);
+gamgi_io_token_cut (path, fullname, GAMGI_IO_PATHNAME);
 length = strlen (fullname);
 
 /*********************
@@ -250,7 +250,7 @@ if (directory != NULL)
      * GAMGI_IO_FULLNAME must be >= GAMGI_IO_PATHNAME + GAMGI_IO_SHORTNAME *
      ***********************************************************************/
 
-    strncpy (fullname + length, child->d_name, GAMGI_IO_SHORTNAME - 1);
+    gamgi_io_token_cut (child->d_name, fullname + length, GAMGI_IO_SHORTNAME);
     if (static_dir (fullname) == FALSE)
       {
       if (static_hide_files (child->d_name, window) == TRUE) continue;
@@ -534,15 +534,14 @@ if (name == NULL || gamgi_io_token_size_check (name,
 GAMGI_IO_PATHNAME - 1) == FALSE) gtk_widget_set_sensitive (button_home, FALSE);
 else { strcpy (home, name); strcat (home, "/"); }
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_current");
 if (getcwd (current, sizeof (current)) == NULL ||
 gamgi_io_token_size_check (current, GAMGI_IO_PATHNAME - 1) == FALSE)
   gtk_widget_set_sensitive (button_current, FALSE);
 else strcat (current, "/");
 
 if (strcmp (last, "") != 0) button = button_last;
-else if (GTK_WIDGET_SENSITIVE (button_current) == TRUE) button = button_current;
-else if (GTK_WIDGET_SENSITIVE (button_home) == TRUE) button = button_home;
+else if (gtk_widget_is_sensitive (button_current) == TRUE) button = button_current;
+else if (gtk_widget_is_sensitive (button_home) == TRUE) button = button_home;
 else button = button_root;
 
 gtk_button_clicked (GTK_BUTTON (button));
