@@ -51,10 +51,7 @@ for (window = gamgi->window_start; window != NULL; window = window->next)
   gamgi_gtk_window_remove_dialogs (window);
 
 for (window = gamgi->window_start; window != NULL; window = window->next)
-  {
-  gamgi_gtk_window_remove_timers (window);
   gamgi_gtk_window_remove_window (window);
-  }
 
 /***********************************************
  * quit the gtk main loop: execution continues *
