@@ -105,10 +105,11 @@ GAMGI_GTK_CLUSTER_REMOVE, GAMGI_GTK_CLUSTER_CONFIG,
 
 GAMGI_GTK_CELL_CREATE, GAMGI_GTK_CELL_COPY, 
 GAMGI_GTK_CELL_SELECT, GAMGI_GTK_CELL_LINK, 
-GAMGI_GTK_CELL_LINK_RCP, GAMGI_GTK_CELL_LINK_POLYTOPE, GAMGI_GTK_CELL_MODIFY, 
-GAMGI_GTK_CELL_MEASURE, GAMGI_GTK_CELL_MEASURE_RECIPROCAL,
-GAMGI_GTK_CELL_ANIMATE, GAMGI_GTK_CELL_REMOVE, 
-GAMGI_GTK_CELL_CONFIG,
+GAMGI_GTK_CELL_LINK_RCP, GAMGI_GTK_CELL_LINK_POLYTOPE,
+GAMGI_GTK_CELL_MODIFY, GAMGI_GTK_CELL_MEASURE,
+GAMGI_GTK_CELL_MEASURE_GEOMETRY, GAMGI_GTK_CELL_MEASURE_RECIPROCAL,
+GAMGI_GTK_CELL_MEASURE_VORONOI, GAMGI_GTK_CELL_ANIMATE,
+GAMGI_GTK_CELL_REMOVE, GAMGI_GTK_CELL_CONFIG,
 
 GAMGI_GTK_ARROW_CREATE, GAMGI_GTK_ARROW_COPY, 
 GAMGI_GTK_ARROW_SELECT, GAMGI_GTK_ARROW_LINK, 
@@ -310,7 +311,7 @@ GAMGI_GTK_GAMGI_EXIT, GAMGI_GTK_GAMGI_CONFIG };
 #define GAMGI_GTK_HELP_TUTORIAL_HEIGHT 400
 
 /***********************************
- * minimum dimensions for Cell     *
+ * min,max dimensions for Cell     *
  * Systems,Lattice,Groups windows. *
  ***********************************/
 
