@@ -45,10 +45,28 @@ gtk_widget_destroy (*dialog);
  *                                             *
  ***********************************************/
 
-void gamgi_gtk_dialog_delete (GtkWidget *widget,
+int gamgi_gtk_dialog_delete (GtkWidget *widget,
 GdkEventButton *event, void *data)
 {
 gamgi_gtk_dialog_remove (widget, data);
+
+/*************************
+ * FALSE: destroy window *
+ *************************/
+
+return FALSE;
+}
+
+void gamgi_gtk_dialog_global_remove (void)
+{
+/*************************
+ * remove global dialogs *
+ *************************/
+
+if (gamgi->message != NULL)
+  gamgi_gtk_dialog_remove (gamgi->message, &gamgi->message);
+if (gamgi->question != NULL)
+  gamgi_gtk_dialog_remove (gamgi->question, &gamgi->question);
 }
 
 /************* external function ******************
@@ -111,10 +129,16 @@ gamgi_gtk_dialog_remove (NULL, &window->dialog1);
  *                                             *
  ***********************************************/
 
-void gamgi_gtk_dialog_task0_delete (GtkWidget *widget, 
+int gamgi_gtk_dialog_task0_delete (GtkWidget *widget, 
 GdkEventButton *event, void *data)
 {
 gamgi_gtk_dialog_task0_remove (widget, data);
+
+/*************************
+ * FALSE: destroy window *
+ *************************/
+
+return FALSE;
 }
 
 /************* external function ***************
@@ -128,10 +152,16 @@ gamgi_gtk_dialog_task0_remove (widget, data);
  *                                             *
  ***********************************************/
 
-void gamgi_gtk_dialog_task1_delete (GtkWidget *widget, 
+int gamgi_gtk_dialog_task1_delete (GtkWidget *widget, 
 GdkEventButton *event, void *data)
 {
 gamgi_gtk_dialog_task1_remove (widget, data);
+
+/*************************
+ * FALSE: destroy window *
+ *************************/
+
+return FALSE;
 }
 
 void gamgi_gtk_dialog_color (GdkColor *color, 
@@ -288,11 +318,9 @@ return button;
 void gamgi_gtk_dialog_titles_scan (GtkCellLayout *layout,
 GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, void *data)
 {
-gamgi_bool sensitive;
+gamgi_bool sensitive = TRUE;
 
-sensitive = TRUE;
-if (gtk_tree_model_iter_has_child (model, iter) == TRUE)
-  sensitive = FALSE;
+if (gtk_tree_model_iter_has_child (model, iter) == TRUE) sensitive = FALSE;
 
 g_object_set (renderer, "sensitive", sensitive, NULL);
 }
