@@ -296,6 +296,8 @@ if (window->action == GAMGI_GTK_MOLECULE_MEASURE)
   action = GAMGI_GTK_MOLECULE_MEASURE_GEOMETRY;
 if (window->action == GAMGI_GTK_CLUSTER_MEASURE)
   action = GAMGI_GTK_CLUSTER_MEASURE_GEOMETRY;
+if (window->action == GAMGI_GTK_CELL_MEASURE)
+  action = GAMGI_GTK_CELL_MEASURE_GEOMETRY;
 
 dialog = gamgi_gtk_dialog_report_create (text, 
 "Measure Geometry", action, window);
@@ -890,7 +892,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   cluster->faces = TRUE;
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "voronoi_button_atoms");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
-  cluster->n_dots = TRUE;
+  cluster->atoms = TRUE;
 
 /********************************
  * get borders combo box option *
@@ -934,6 +936,8 @@ if (window->action == GAMGI_GTK_MOLECULE_MEASURE)
   action = GAMGI_GTK_MOLECULE_MEASURE_VORONOI;
 if (window->action == GAMGI_GTK_CLUSTER_MEASURE)
   action = GAMGI_GTK_CLUSTER_MEASURE_VORONOI;
+if (window->action == GAMGI_GTK_CELL_MEASURE)
+  action = GAMGI_GTK_CELL_MEASURE_VORONOI;
 
 dialog = gamgi_gtk_dialog_report_create (text, 
 "Measure Voronoi", action, window);
