@@ -36,10 +36,6 @@ gamgi_bool gamgi_gtk_statusbar_layer_timeout (void *data);
 
 gamgi_bool gamgi_gtk_statusbar_time_timeout (void *data);
 
-void gamgi_gtk_statusbar_focus_modify (gamgi_window *window);
-
-void gamgi_gtk_statusbar_layer_modify (gamgi_window *window);
-
 void gamgi_gtk_statusbar_message_show (gamgi_window *window, 
 char *text, char *color, int time);
 
