@@ -91,6 +91,27 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
 
+static void static_start_container (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+GtkWidget *button;
+
+/**********************
+ * start central Atom *
+ **********************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom");
+gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+/************************************
+ * start central atom in Local mode *
+ ************************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_local");
+gtk_button_clicked (GTK_BUTTON (button));
+}
+
 static void static_start_polytope (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -158,28 +179,7 @@ sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 }
 
-static void static_start_container (gamgi_window *window)
-{
-GtkWidget *dialog = window->dialog0;
-GtkWidget *entry;
-GtkWidget *button;
-
-/**********************
- * start central Atom *
- **********************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom");
-gtk_entry_set_text (GTK_ENTRY (entry), "");
-
-/************************************
- * start central atom in Local mode *
- ************************************/
-
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_local");
-gtk_button_clicked (GTK_BUTTON (button));
-}
-
-static void static_type (GtkWidget *widget, void *data)
+static void static_reference (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -245,7 +245,7 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 char string[2 * GAMGI_ENGINE_TOKEN];
 
-group->type = GAMGI_CHEM_CONTAINER;
+group->reference = GAMGI_CHEM_CONTAINER;
 
 /************
  * get name *
@@ -310,7 +310,7 @@ double visible, coplanar, radius;
 int out[4];
 int number, element;
 
-group->type = GAMGI_CHEM_POLYTOPE;
+group->reference = GAMGI_CHEM_POLYTOPE;
 
 /************
  * get name *
@@ -694,7 +694,7 @@ gtk_widget_set_size_request (notebook, size.width, size.height);
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_container");
 gtk_button_clicked (GTK_BUTTON (button));
-static_type (NULL, window);
+static_reference (NULL, window);
 }
 
 static void static_press (gamgi_object *object, void *data)
@@ -833,9 +833,9 @@ vbox_top = gtk_vbox_new (FALSE, 20);
 gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/********
- * Type *
- ********/
+/*************
+ * Reference *
+ *************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
@@ -852,7 +852,7 @@ gtk_widget_show (label);
 button = gtk_radio_button_new_with_label (NULL, "Container");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "clicked",
-G_CALLBACK (static_type), window);
+G_CALLBACK (static_reference), window);
 g_object_set_data (G_OBJECT (dialog), "button_container", button);
 gtk_widget_show (button);
 
@@ -860,7 +860,7 @@ button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Polytope");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "clicked",
-G_CALLBACK (static_type), window);
+G_CALLBACK (static_reference), window);
 g_object_set_data (G_OBJECT (dialog), "button_polytope", button);
 gtk_widget_show (button);
 
