@@ -220,7 +220,7 @@ static void static_group (gamgi_group *group, gamgi_window *window)
 {
 gamgi_dlist *dlist;
 
-if (group->type == GAMGI_CHEM_POLYTOPE)
+if (group->reference == GAMGI_CHEM_POLYTOPE)
   {
   if (cache.new[STATIC_STYLE] == TRUE) group->faces = cache.style;
   if (cache.new[STATIC_RED] == TRUE) group->red = cache.red;
@@ -1204,7 +1204,7 @@ if (cache.reference == STATIC_REFERENCE_CONTAINER)
    ****************/
 
   strcpy (group->object.name, name);
-  group->type = GAMGI_CHEM_CONTAINER;
+  group->reference = GAMGI_CHEM_CONTAINER;
 
   /*************************************
    *  launch a Group Link dialog       *
@@ -1253,7 +1253,7 @@ if (cache.reference == STATIC_REFERENCE_POLYTOPE)
    ****************/
 
   strcpy (group->object.name, name);
-  group->type = GAMGI_CHEM_POLYTOPE;
+  group->reference = GAMGI_CHEM_POLYTOPE;
   group->faces = style;
   group->red = red;
   group->green = green;
@@ -1320,7 +1320,7 @@ if (cache.reference == STATIC_REFERENCE_LOCAL)
   {
   strcpy (group->object.name, name);
 
-  if (group->type == GAMGI_CHEM_CONTAINER) static_group (group, window);
+  if (group->reference == GAMGI_CHEM_CONTAINER) static_group (group, window);
   else
     {
     group->faces = style;
@@ -1577,7 +1577,7 @@ if (class == GAMGI_ENGINE_GROUP)
    * set Group style, color, scale *
    *********************************/
 
-  if (group->type == GAMGI_CHEM_POLYTOPE)
+  if (group->reference == GAMGI_CHEM_POLYTOPE)
     {
     combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
     gtk_combo_box_set_active (GTK_COMBO_BOX (combo), group->faces);
@@ -1595,7 +1595,7 @@ if (class == GAMGI_ENGINE_GROUP)
     gtk_entry_set_text (GTK_ENTRY (entry), string);
     }
 
-  if (group->type == GAMGI_CHEM_CONTAINER)
+  if (group->reference == GAMGI_CHEM_CONTAINER)
     {
     combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
     gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_STYLE_LOCAL);
