@@ -13,10 +13,19 @@
  * internal functions *
  **********************
 
-static gamgi_bool static_scan (gamgi_group *group, gamgi_dlist *start,
-double *position, gamgi_atom **central);
+static void static_text (gamgi_text *text);
 
-static gamgi_bool static_find (gamgi_group *group, gamgi_atom **atom);
+static void static_orbital (gamgi_orbital *orbital);
+
+static void static_bond (gamgi_bond *bond);
+
+static void static_atom (gamgi_atom *atom);
+
+static void static_direction (gamgi_direction *direction);
+
+static void static_plane (gamgi_plane *plane);
+
+static void static_group (gamgi_group *group);
 
 static void static_remove (gamgi_group *group);
 
@@ -24,15 +33,27 @@ static gamgi_enum static_class (gamgi_window *window);
 
 static void static_number (GtkWidget *widget, void *data);
 
+static void static_absolute (GtkWidget *dialog);
+
+static void static_relative (GtkWidget *dialog);
+
+static void static_color (GtkWidget *widget, void *data);
+
 static void static_start_polytope (gamgi_window *window);
 
 static void static_start_container (gamgi_window *window);
 
 static void static_start_position (gamgi_window *window);
 
-static void static_autonomy (GtkWidget *widget, void *data);
+static void static_start_view (gamgi_window *window);
 
-static void static_type (GtkWidget *widget, void *data);
+static void static_reference (GtkWidget *widget, void *data);
+
+static void static_translation (GtkWidget *widget, void *data);
+
+static void static_rotation (GtkWidget *widget, void *data);
+
+static void static_reset (gamgi_window *window);
 
 static void static_list (GtkWidget *widget, void *data);
 
