@@ -70,7 +70,7 @@ switch (window->action)
 
   case GAMGI_GTK_TEXT_LINK:
   gamgi_gtk_help_dialog_import ("Help Text Link",  
-  "interfaces/text/link", window, 1, n, "object");
+  "interfaces/text/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_TEXT_MODIFY:
@@ -91,7 +91,7 @@ switch (window->action)
   case GAMGI_GTK_ORBITAL_CREATE:
   gamgi_gtk_help_dialog_import ("Help Orbital Create",  
   "interfaces/orbital/create", window, 5, n,
-  "type", "model", "volume", "position", "view");
+  "type", "scope", "volume", "position", "view");
   break;
 
   case GAMGI_GTK_ORBITAL_COPY:
@@ -101,7 +101,7 @@ switch (window->action)
 
   case GAMGI_GTK_ORBITAL_SELECT:
   gamgi_gtk_help_dialog_import ("Help Orbital Select",  
-  "interfaces/orbital/select", window, 0, n);
+  "interfaces/orbital/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_ORBITAL_LINK:
@@ -112,7 +112,7 @@ switch (window->action)
   case GAMGI_GTK_ORBITAL_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Orbital Modify",  
   "interfaces/orbital/modify", window, 5, n,
-  "type", "model", "volume", "position", "view");
+  "type", "scope", "volume", "position", "view");
   break;
 
   case GAMGI_GTK_ORBITAL_REMOVE:
@@ -196,8 +196,8 @@ switch (window->action)
 
   case GAMGI_GTK_ATOM_CONFIG:
   gamgi_gtk_help_dialog_import ("Help Atom Config",
-  "interfaces/atom/config", window, 3, n, "element",
-  "analysis", "view");
+  "interfaces/atom/config", window, 4, n, "type",
+  "analysis", "view", "global");
   break;
 
   case GAMGI_GTK_DIRECTION_CREATE:
@@ -339,7 +339,7 @@ switch (window->action)
 
   case GAMGI_GTK_MOLECULE_CREATE:
   gamgi_gtk_help_dialog_import ("Help Molecule Create",  
-  "interfaces/molecule/create", window, 0, n);
+  "interfaces/molecule/create", window, 1, n, "type");
   break;
 
   case GAMGI_GTK_MOLECULE_COPY:
@@ -484,7 +484,18 @@ switch (window->action)
 
   case GAMGI_GTK_CELL_MEASURE:
   gamgi_gtk_help_dialog_import ("Help Cell Measure",  
-  "interfaces/cell/measure", window, 1, n, "reciprocal");
+  "interfaces/cell/measure", window, 5, n, "type",
+  "reciprocal", "voronoi", "tolerance", "view");
+  break;
+
+  case GAMGI_GTK_CELL_MEASURE_GEOMETRY:
+  gamgi_gtk_help_dialog_import ("Help Cell Measure Geometry",
+  "interfaces/cell/geometry", window, 0, n);
+  break;
+
+  case GAMGI_GTK_CELL_MEASURE_VORONOI:
+  gamgi_gtk_help_dialog_import ("Help Cell Measure Voronoi",
+  "interfaces/cell/voronoi", window, 0, n);
   break;
 
   case GAMGI_GTK_CELL_ANIMATE:
@@ -497,6 +508,12 @@ switch (window->action)
   "interfaces/cell/remove", window, 1, n, "object");
   break;
 
+  case GAMGI_GTK_CELL_CONFIG:
+  gamgi_gtk_help_dialog_import ("Help Cell Config",
+  "interfaces/cell/config", window, 4, n, "volume",
+  "origin", "view", "global");
+  break;
+
   case GAMGI_GTK_ARROW_CREATE:
   gamgi_gtk_help_dialog_import ("Help Arrow Create",  
   "interfaces/arrow/create", window, 0, n);
@@ -654,7 +671,7 @@ switch (window->action)
 
   case GAMGI_GTK_LIGHT_CONFIG:
   gamgi_gtk_help_dialog_import ("Help Light Config", 
-  "interfaces/light/config", window, 2, n, "color", "materials");
+  "interfaces/light/config", window, 2, n, "color", "global");
   break;
 
   case GAMGI_GTK_LAYER_CREATE:
