@@ -285,7 +285,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Light Remove",
 static void static_interfaces_light_config (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Light Config", 
-"interfaces/light/config", data, 2, 1, "color", "materials");
+"interfaces/light/config", data, 2, 1, "color", "global");
 }
 
 static void static_interfaces_assembly (void *data)
@@ -408,7 +408,20 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Cell Modify",
 static void static_interfaces_cell_measure (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Cell Measure", 
-"interfaces/cell/measure", data, 1, 1, "reciprocal");
+"interfaces/cell/measure", data, 5, 1, "type", "reciprocal",
+"voronoi", "tolerance", "view");
+}
+
+static void static_interfaces_cell_measure_geometry (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Cell Measure Geometry",
+"interfaces/cell/geometry", data, 0, 0);
+}
+
+static void static_interfaces_cell_measure_voronoi (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Cell Measure Voronoi",
+"interfaces/cell/voronoi", data, 0, 0);
 }
 
 static void static_interfaces_cell_remove (void *data)
@@ -417,6 +430,13 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Cell Remove",
 "interfaces/cell/remove", data, 1, 1, "object");
 }
 
+static void static_interfaces_cell_config (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Cell Config",
+"interfaces/cell/config", data, 4, 1, "volume", "origin",
+"view", "global");
+}
+
 static void static_interfaces_cluster (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Cluster", 
@@ -487,7 +507,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Molecule",
 static void static_interfaces_molecule_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Molecule Create", 
-"interfaces/molecule/create", data, 0, 0);
+"interfaces/molecule/create", data, 1, 1, "type");
 }
 
 static void static_interfaces_molecule_copy (void *data)
@@ -594,7 +614,6 @@ static void static_interfaces_group_measure (void *data)
 gamgi_gtk_help_dialog_import ("Help Interfaces Group Measure",
 "interfaces/group/measure", data, 5, 1, "type", "symmetry",
 "voronoi", "tolerance", "view");
-
 }
 
 static void static_interfaces_group_measure_geometry (void *data)
@@ -774,8 +793,8 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Atom Remove",
 static void static_interfaces_atom_config (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Atom Config", 
-"interfaces/atom/config", data, 3, 1, "element",
-"analysis", "view");
+"interfaces/atom/config", data, 4, 1, "type",
+"analysis", "view", "global");
 }
 
 static void static_interfaces_bond (void *data)
@@ -831,7 +850,7 @@ static void static_interfaces_orbital_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Create",
 "interfaces/orbital/create", data, 5, 1,
-"type", "model", "volume", "position", "view");
+"type", "scope", "volume", "position", "view");
 }
 
 static void static_interfaces_orbital_copy (void *data)
@@ -843,7 +862,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Copy",
 static void static_interfaces_orbital_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Select", 
-"interfaces/orbital/select", data, 0, 0);
+"interfaces/orbital/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_orbital_link (void *data)
@@ -856,7 +875,7 @@ static void static_interfaces_orbital_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Modify",
 "interfaces/orbital/modify", data, 5, 1,
-"type", "model", "volume", "position", "view");
+"type", "scope", "volume", "position", "view");
 }
 
 static void static_interfaces_orbital_remove (void *data)
@@ -919,24 +938,18 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Help",
 "keywords/help", data, 0, 0);
 }
 
-static void static_interfaces_help_start (void *data)
-{
-gamgi_gtk_help_dialog_import ("Help Interfaces Help Start", 
-"interfaces/help/start", data, 0, 0);
-}
-
-static void static_interfaces_help_topic (void *data)
-{
-gamgi_gtk_help_dialog_import ("Help Interfaces Help Topic", 
-"interfaces/help/topic", data, 0, 0);
-}
-
 static void static_interfaces_help_current (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Help Current", 
 "interfaces/help/current", data, 0, 0);
 }
 
+static void static_interfaces_help_topic (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Help Topic",
+"interfaces/help/topic", data, 0, 0);
+}
+
 static void static_interfaces_help_search (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Help Search", 
@@ -949,6 +962,18 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Help Tutorial",
 "interfaces/help/tutorial", data, 0, 0);
 }
 
+static void static_interfaces_help_tips (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Help Tips",
+"interfaces/help/tips", data, 0, 0);
+}
+
+static void static_interfaces_help_start (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Help Start",
+"interfaces/help/start", data, 0, 0);
+}
+
 static void static_interfaces_help_config (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Help Config", 
@@ -1131,7 +1156,7 @@ gamgi_gtk_help_dialog_import ("Help Formats Light Create",
 static void static_formats_light_config (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Light Config",
-"formats/light/config", data, 2, 1, "color", "materials");
+"formats/light/config", data, 2, 1, "color", "global");
 }
 
 static void static_formats_assembly (void *data)
@@ -1155,7 +1180,7 @@ gamgi_gtk_help_dialog_import ("Help Formats Graph",
 static void static_formats_graph_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Graph Create",
-"formats/graph", data, 1, 1, "view");
+"formats/graph/create", data, 1, 1, "view");
 }
 
 static void static_formats_arrow (void *data)
@@ -1210,7 +1235,8 @@ gamgi_gtk_help_dialog_import ("Help Formats Cluster",
 static void static_formats_cluster_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Cluster Create",
-"formats/cluster/create", data, 1, 1, "view");
+"formats/cluster/create", data, 4, 1, "type", "scope",
+"position", "view");
 }
 
 static void static_formats_molecule (void *data)
@@ -1234,7 +1260,8 @@ gamgi_gtk_help_dialog_import ("Help Formats Group",
 static void static_formats_group_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Group Create",
-"formats/group/create", data, 1, 1, "view");
+"formats/group/create", data, 4, 1, "type", "scope",
+"position", "view");
 }
 
 static void static_formats_plane (void *data)
@@ -1246,8 +1273,8 @@ gamgi_gtk_help_dialog_import ("Help Formats Plane",
 static void static_formats_plane_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Plane Create",
-"formats/plane/create", data, 4, 1, "type", "projection", 
-"scope", "view");
+"formats/plane/create", data, 5, 1, "type", "projection", 
+"scope", "position", "view");
 }
 
 static void static_formats_direction (void *data)
@@ -1259,8 +1286,8 @@ gamgi_gtk_help_dialog_import ("Help Formats Direction",
 static void static_formats_direction_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Direction Create",
-"formats/direction/create", data, 4, 1, "type", "projection", 
-"scope", "view");
+"formats/direction/create", data, 5, 1, "type", "projection", 
+"scope", "position", "view");
 }
 
 static void static_formats_atom (void *data)
@@ -1309,7 +1336,7 @@ gamgi_gtk_help_dialog_import ("Help Formats Orbital",
 static void static_formats_orbital_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Orbital Create",
-"formats/orbital/create", data, 5, 1, "type", "model",
+"formats/orbital/create", data, 5, 1, "type", "scope",
 "volume", "position", "view");
 }
 
@@ -1480,8 +1507,11 @@ static_row (store, &iter2, "Select", static_interfaces_cell_select);
 iter3 = static_row (store, &iter2, "Link", static_interfaces_cell_link);
 static_row (store, &iter3, "RCP", static_interfaces_cell_link_rcp);
 static_row (store, &iter2, "Modify", static_interfaces_cell_modify);
-static_row (store, &iter2, "Measure", static_interfaces_cell_measure);
+iter3 = static_row (store, &iter2, "Measure", static_interfaces_cell_measure);
+static_row (store, &iter3, "Geometry", static_interfaces_cell_measure_geometry);
+static_row (store, &iter3, "Voronoi", static_interfaces_cell_measure_voronoi);
 static_row (store, &iter2, "Remove", static_interfaces_cell_remove);
+static_row (store, &iter2, "Config", static_interfaces_cell_config);
 
 iter2 = static_row (store, &iter1, "Cluster", static_interfaces_cluster);
 static_row (store, &iter2, "Create", static_interfaces_cluster_create);
@@ -1511,12 +1541,12 @@ static_row (store, &iter2, "Copy", static_interfaces_group_copy);
 static_row (store, &iter3, "Polytope", static_interfaces_group_create_polytope);
 static_row (store, &iter2, "Select", static_interfaces_group_select);
 static_row (store, &iter2, "Link", static_interfaces_group_link);
+iter3 = static_row (store, &iter2, "Modify", static_interfaces_group_modify);
+static_row (store, &iter3, "Polytope", static_interfaces_group_modify_polytope);
 iter3 = static_row (store, &iter2, "Measure", static_interfaces_group_measure);
 static_row (store, &iter3, "Geometry", static_interfaces_group_measure_geometry);
 static_row (store, &iter3, "Symmetry", static_interfaces_group_measure_symmetry);
 static_row (store, &iter3, "Voronoi", static_interfaces_group_measure_voronoi);
-iter3 = static_row (store, &iter2, "Modify", static_interfaces_group_modify);
-static_row (store, &iter3, "Polytope", static_interfaces_group_modify_polytope);
 static_row (store, &iter2, "Remove", static_interfaces_group_remove);
 
 iter2 = static_row (store, &iter1, "Plane", static_interfaces_plane);
@@ -1573,11 +1603,12 @@ static_row (store, &iter2, "Remove", static_interfaces_text_remove);
 static_row (store, &iter2, "Config", static_interfaces_text_config);
 
 iter2 = static_row (store, &iter1, "Help", static_interfaces_help);
-static_row (store, &iter2, "Start", static_interfaces_help_start);
-static_row (store, &iter2, "Topic", static_interfaces_help_topic);
 static_row (store, &iter2, "Current", static_interfaces_help_current);
+static_row (store, &iter2, "Topic", static_interfaces_help_topic);
 static_row (store, &iter2, "Search", static_interfaces_help_search);
 static_row (store, &iter2, "Tutorial", static_interfaces_help_tutorial);
+static_row (store, &iter2, "Tips", static_interfaces_help_tips);
+static_row (store, &iter2, "Start", static_interfaces_help_start);
 static_row (store, &iter2, "Config", static_interfaces_help_config);
 
 /****************
