@@ -560,12 +560,14 @@ gamgi_global_selection_undo ();
 
 if (cache.above == TRUE)
   {
-  /******************************
-   * link each listed layer to  *
-   * the parent selected window *
-   ******************************/
+  /*******************************************
+   * link above: link each listed layer      *
+   * (child) to the selected window (parent) *
+   *******************************************/
 
   parent = cache.object;
+  window_parent = GAMGI_CAST_WINDOW parent;
+  layer_child = window_parent->layer;
 
   start = NULL;
   for (dlist = gamgi->layers; dlist != NULL; dlist = dlist->next)
@@ -580,20 +582,18 @@ if (cache.above == TRUE)
       }
     }
 
-  /*********************************************
-   * raise to top window and last layer to top *
-   *********************************************/
+  /**************************************
+   * raise to top window and last layer *
+   **************************************/
 
-  window_parent = GAMGI_CAST_WINDOW parent;
   gamgi_gtk_object_raise (layer_child, window_parent);
   } 
-
-if (cache.above == FALSE)
+else
   {
-  /******************************************
-   * link each listed layer to a child      *
-   * object copied from the selected object *
-   ******************************************/
+  /**************************************************
+   * link below: link each listed layer (parent) to *
+   * a child object copied from the selected object *
+   **************************************************/
 
   child = cache.object;
 
@@ -649,6 +649,10 @@ if (static_grab (window_dialog) == FALSE) return;
 
 if (cache.above == TRUE)
   {
+  /***********************************************************************
+   * link above: link selected layer (child) to selected window (parent) *
+   ***********************************************************************/
+
   child = GAMGI_CAST_OBJECT layer;
   parent = cache.object;
 
@@ -656,9 +660,12 @@ if (cache.above == TRUE)
   window_parent = GAMGI_CAST_WINDOW parent;
   layer_parent = GAMGI_CAST_LAYER child;
   }
-
-if (cache.above == FALSE)
+else
   {
+  /***********************************************************************
+   * link below: link selected layer (parent) to selected object (child) *
+   ***********************************************************************/
+
   child = cache.object;
   parent = GAMGI_CAST_OBJECT layer;
 
