@@ -187,40 +187,6 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-static void static_method_axes (char *label, gamgi_window *window)
-{
-GtkWidget *dialog = window->dialog0;
-GtkWidget *widget;
-GtkWidget *hbox;
-GtkWidget *combo;
-GtkListStore *store;
-GtkCellRenderer *renderer;
-GtkTreeIter iter;
-
-widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
-hbox = gtk_widget_get_parent (widget);
-gtk_widget_destroy (widget);
-
-combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), label, combo);
-gtk_widget_show (combo);
-
-store = gtk_list_store_new (1, G_TYPE_STRING);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, " Yes ", -1);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, " No ", -1);
-gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-renderer = gtk_cell_renderer_text_new ();
-gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
-gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
-
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-}
-
 static void static_method (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -261,6 +227,11 @@ if (strcmp (name, "Pick") == 0)
   gamgi_gtk_select_method_direct ("widget_min", window);
   gamgi_gtk_select_method_direct ("widget_max", window);
   }
+else if (strcmp (name, "Axes") == 0)
+  {
+  gamgi_gtk_select_method_bool ("widget_min", window);
+  gamgi_gtk_select_method_bool ("widget_max", window);
+  }
 else if (strcmp (name, "Type") == 0)
   {
   static_method_projection ("widget_min", window);
@@ -271,11 +242,6 @@ else if (strcmp (name, "Inside") == 0 || strcmp (name, "Outside") == 0)
   static_method_visibility ("widget_min", window);
   static_method_visibility ("widget_max", window);
   }
-else if (strcmp (name, "Axes") == 0)
-  {
-  static_method_axes ("widget_min", window);
-  static_method_axes ("widget_max", window);
-  }
 else
   {
   gamgi_gtk_select_method_default ("widget_min", window);
@@ -1387,7 +1353,6 @@ GtkWidget *frame;
 GtkWidget *treeview;
 GtkWidget *combo;
 GtkWidget *button;
-GtkWidget *entry;
 GtkWidget *label;
 GtkWidget *hbox_center, *hbox_left;
 GtkWidget *vbox_dialog, *vbox_page, *vbox_top, *vbox_top_top;
@@ -1685,12 +1650,13 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-g_object_set_data (G_OBJECT (dialog), "widget_min", entry);
-gtk_widget_show (entry);
+/**********************************************
+ * this widget will be removed in static_init *
+ **********************************************/
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "widget_min", combo);
 
 /*******
  * Max *
@@ -1708,12 +1674,13 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-g_object_set_data (G_OBJECT (dialog), "widget_max", entry);
-gtk_widget_show (entry);
+/**********************************************
+ * this widget will be removed in static_init *
+ **********************************************/
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "widget_max", combo);
 
 /*********************
  * Ok/Cancel buttons *
