@@ -17,7 +17,7 @@ static gamgi_enum static_class (gamgi_window *window);
 
 static void static_default_layer (gamgi_window *window);
 
-nstatic void static_location (GtkWidget *widget, void *data);
+nstatic void static_destination (GtkWidget *widget, void *data);
 
 static void static_reset (gamgi_window *window);
 
