@@ -232,7 +232,7 @@ vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_proj
 
 cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
 "entry_cell", GAMGI_ENGINE_CELL, window);
-if (cell != NULL && cell->type == GAMGI_PHYS_PROJECTION)
+if (cell != NULL && cell->model == GAMGI_PHYS_PROJECTION)
   {
   gtk_widget_hide (vbox_scope);
   gtk_widget_show (vbox_projection);
@@ -604,10 +604,10 @@ GtkWidget *button;
  * get projection: Wulff or Schmidt *
  ************************************/
 
-plane->projection = gamgi_phys_projection_wulff;
+plane->net = gamgi_phys_projection_wulff;
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_schmidt");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
-  plane->projection = gamgi_phys_projection_schmidt;
+  plane->net = gamgi_phys_projection_schmidt;
 
 /********************************
  * get plane model: pole, trace *
@@ -750,7 +750,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
    ************************************/
 
   if (static_ok_cell (plane, &cell, window) == FALSE) return;
-  if (cell->type == GAMGI_PHYS_PROJECTION)
+  if (cell->model == GAMGI_PHYS_PROJECTION)
     {
     if (static_ok_projection (plane, &pole, &trace, window) == FALSE) return;
     }
@@ -791,7 +791,7 @@ if (plane->reference == GAMGI_ENGINE_CELL)
    ************************************/
 
   dlist = NULL;
-  if (cell->type != GAMGI_PHYS_PROJECTION)
+  if (cell->model != GAMGI_PHYS_PROJECTION)
     {
     dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
     dlist = gamgi_engine_filter_atom (dlist, 0, filter,
@@ -818,7 +818,7 @@ if (plane->reference == GAMGI_ENGINE_ATOM)
 
   if (strcmp (plane->object.name, "") == 0)
     strcpy (plane->object.name, "Plane");
-  plane->type = GAMGI_PHYS_POLYGON;
+  plane->model = GAMGI_PHYS_POLYGON;
   plane->vectors = GAMGI_PHYS_PLANE_VECTORS;
 
   parent = gamgi_phys_plane_parent (atom1, atom2, atom3, window);
@@ -1146,9 +1146,9 @@ vbox_top = gtk_vbox_new (FALSE, 10);
 gtk_box_pack_start (GTK_BOX (vbox_page), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/********
- * Type *
- ********/
+/*************
+ * Reference *
+ *************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
