@@ -504,10 +504,16 @@ if (static_update (value, window) == TRUE) static_show (window);
 static_hide (window);
 }
 
-static void static_delete (GtkWidget *widget,
+static int static_delete (GtkWidget *widget,
 GdkEventButton *event, void *data)
 {
 gamgi_gtk_plane_list_cancel (widget, data);
+
+/*************************
+ * FALSE: destroy window *
+ *************************/
+
+return FALSE;
 }
 
 static void static_include (GtkWidget *widget, void *data)
@@ -772,7 +778,7 @@ static void static_plane (gamgi_plane *plane, gamgi_cell *cell,
 gamgi_enum structure, gamgi_enum filter, double thickness,
 gamgi_dlist *dlist, int start, int end, gamgi_enum pole, gamgi_enum trace)
 {
-if (cell->type == GAMGI_PHYS_PROJECTION)
+if (cell->model == GAMGI_PHYS_PROJECTION)
   gamgi_phys_plane_projection (plane, cell, pole, trace);
 else
   gamgi_phys_plane_range (plane, cell,
