@@ -77,8 +77,8 @@ gamgi_enum structure, filter;
 double thickness;
 int order;
 int node[4];
-gamgi_projection projection;
-gamgi_enum type;
+gamgi_net net;
+gamgi_enum model;
 double translation[3], rotation[3];
 float red, green, blue;
 double scale; } cache;
@@ -491,9 +491,9 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget *combo;
 int row;
 
-/******************************************************
- * default for projection and type combo boxes: Local *
- ******************************************************/
+/*******************************************************
+ * default for projection and model combo boxes: Local *
+ *******************************************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
@@ -651,7 +651,7 @@ cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
 "entry_cell", GAMGI_ENGINE_CELL, window);
 if (cell != NULL)
   {
-  if (cell->type == GAMGI_PHYS_PROJECTION)
+  if (cell->model == GAMGI_PHYS_PROJECTION)
     {
     gtk_widget_hide (vbox_scope);
     gtk_widget_hide (vbox_position);
@@ -795,10 +795,10 @@ gamgi_bool visible;
 const char *name;
 int row;
 
-/***************************************************
- * type: Cell, Atom1,Atom2,Atom3 are required when *
- * Reference is explicitly set to Cell or Atoms    *
- ***************************************************/
+/*****************************************************
+ * Cell, Atom1,Atom2,Atom3 objects are required when *
+ * Reference is explicitly set to Cell or Atoms      *
+ *****************************************************/
 
 cache.new[STATIC_REFERENCE] = FALSE;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
@@ -1070,9 +1070,9 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (visible == TRUE && row < STATIC_NET_LOCAL)
   {
   cache.new[STATIC_NET] = TRUE;
-  cache.projection = NULL;
-  if (row == STATIC_NET_WULFF) cache.projection = gamgi_phys_projection_wulff;
-  if (row == STATIC_NET_SCHMIDT) cache.projection = gamgi_phys_projection_schmidt;
+  cache.net = NULL;
+  if (row == STATIC_NET_WULFF) cache.net = gamgi_phys_projection_wulff;
+  if (row == STATIC_NET_SCHMIDT) cache.net = gamgi_phys_projection_schmidt;
   }
 
 cache.new[STATIC_MODEL] = FALSE;
@@ -1081,9 +1081,9 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (visible == TRUE && row < STATIC_MODEL_LOCAL)
   {
   cache.new[STATIC_MODEL] = TRUE;
-  cache.type = FALSE;
-  if (row == STATIC_MODEL_POLE) cache.type = GAMGI_PHYS_POLE;
-  if (row == STATIC_MODEL_TRACE) cache.type = GAMGI_PHYS_TRACE;
+  cache.model = FALSE;
+  if (row == STATIC_MODEL_POLE) cache.model = GAMGI_PHYS_POLE;
+  if (row == STATIC_MODEL_TRACE) cache.model = GAMGI_PHYS_TRACE;
   }
 
 /*********************************
@@ -1246,8 +1246,8 @@ gamgi_cell *cell;
 gamgi_object *parent;
 gamgi_dlist *dlist;
 char name[GAMGI_ENGINE_TOKEN];
-gamgi_projection projection;
-gamgi_enum reference, vectors, type;
+gamgi_net net;
+gamgi_enum reference, vectors, model;
 gamgi_bool link[3];
 gamgi_bool new;
 double zero[3], euler[3], origin[3];
@@ -1274,8 +1274,8 @@ hkl[1] = plane->hkl[1];
 hkl[2] = plane->hkl[2];
 vectors = plane->vectors;
 
-projection = plane->projection;
-type = plane->type;
+net = plane->net;
+model = plane->model;
 order = plane->order;
 
 gamgi_math_position_plane_rotation_get (plane, euler);
@@ -1299,8 +1299,8 @@ if (cache.new[STATIC_K] == TRUE) hkl[1] = cache.hkl[1];
 if (cache.new[STATIC_L] == TRUE) hkl[2] = cache.hkl[2];
 if (cache.new[STATIC_VECTORS] == TRUE) vectors = cache.vectors;
 
-if (cache.new[STATIC_NET] == TRUE) projection = cache.projection;
-if (cache.new[STATIC_MODEL] == TRUE) type = cache.type;
+if (cache.new[STATIC_NET] == TRUE) net = cache.net;
+if (cache.new[STATIC_MODEL] == TRUE) model = cache.model;
 if (cache.new[STATIC_ORDER] == TRUE) order = cache.order;
 
 if (cache.new[STATIC_TRANSLATION_X] == TRUE) origin[0] = cache.translation[0];
@@ -1328,14 +1328,14 @@ if (cache.new[STATIC_REFERENCE] == TRUE)
     hkl[0] = 0; hkl[1] = 0; hkl[2] = 0;
     vectors = GAMGI_PHYS_PLANE_VECTORS;
     order = 1;
-    type = GAMGI_PHYS_POLYGON;
-    projection = NULL;
+    model = GAMGI_PHYS_POLYGON;
+    net = NULL;
     }
 
   if (reference == GAMGI_ENGINE_CELL)
     {
-    if (cell->type == GAMGI_PHYS_PROJECTION) order = 1;
-    else { type = GAMGI_PHYS_POLYGON; projection = NULL; }
+    if (cell->model == GAMGI_PHYS_PROJECTION) order = 1;
+    else { model = GAMGI_PHYS_POLYGON; net = NULL; }
     }
   }
 
@@ -1353,8 +1353,8 @@ if (reference == GAMGI_ENGINE_CELL)
     return FALSE;
     }
 
-  if ((type == GAMGI_PHYS_POLE || type == GAMGI_PHYS_TRACE) &&
-  (projection == NULL || cell == NULL || cell->type != GAMGI_PHYS_PROJECTION))
+  if ((model == GAMGI_PHYS_POLE || model == GAMGI_PHYS_TRACE) &&
+  (net == NULL || cell == NULL || cell->model != GAMGI_PHYS_PROJECTION))
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
@@ -1362,7 +1362,8 @@ if (reference == GAMGI_ENGINE_CELL)
     return FALSE;
     }
 
-  if (type != GAMGI_PHYS_POLE && type != GAMGI_PHYS_TRACE && projection != NULL)
+  if (model != GAMGI_PHYS_POLE && model != GAMGI_PHYS_TRACE &&
+  net != NULL)
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
@@ -1370,7 +1371,7 @@ if (reference == GAMGI_ENGINE_CELL)
     return FALSE;
     }
 
-  if (type == GAMGI_PHYS_VECTOR &&
+  if (model == GAMGI_PHYS_VECTOR &&
   (cache.new[STATIC_TRANSLATION_X] == TRUE ||
   cache.new[STATIC_TRANSLATION_Y] == TRUE ||
   cache.new[STATIC_TRANSLATION_Z] == TRUE ||
@@ -1412,7 +1413,7 @@ if (reference == GAMGI_ENGINE_ATOM)
     return FALSE;
     }
 
-  if (projection != NULL)
+  if (net != NULL)
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
@@ -1420,8 +1421,8 @@ if (reference == GAMGI_ENGINE_ATOM)
     return FALSE;
     }
 
-  if (type == GAMGI_PHYS_POLE || type == GAMGI_PHYS_TRACE ||
-  type == GAMGI_PHYS_VECTOR)
+  if (model == GAMGI_PHYS_POLE || model == GAMGI_PHYS_TRACE ||
+  model == GAMGI_PHYS_VECTOR)
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
@@ -1479,8 +1480,8 @@ if (cache.new[STATIC_NODES] > 0)
   }
 
 if (order != 1 &&
-(reference == GAMGI_ENGINE_ATOM || type == GAMGI_PHYS_POLE ||
-type == GAMGI_PHYS_TRACE || type == GAMGI_PHYS_VECTOR))
+(reference == GAMGI_ENGINE_ATOM || model == GAMGI_PHYS_POLE ||
+model == GAMGI_PHYS_TRACE || model == GAMGI_PHYS_VECTOR))
   {
   if (cache.local == TRUE)
     gamgi_gtk_dialog_message_create ("Error",
@@ -1503,15 +1504,15 @@ if (plane->hkl[2] != hkl[2]) new = TRUE;
 if (plane->vectors != vectors) new = TRUE;
 
 if (plane->order != order) new = TRUE;
-if (plane->projection != projection) new = TRUE;
-if (plane->type != type) new = TRUE;
+if (plane->net != net) new = TRUE;
+if (plane->model != model) new = TRUE;
 
 /*************************************
  * reciprocal lattica cannot be new  *
  * and polygon planes need thickness *
  *************************************/
 
-if (new == TRUE && plane->type == GAMGI_PHYS_VECTOR)
+if (new == TRUE && plane->model == GAMGI_PHYS_VECTOR)
   {
   if (cache.local == TRUE)
     gamgi_gtk_dialog_message_create ("Error",
@@ -1519,7 +1520,7 @@ if (new == TRUE && plane->type == GAMGI_PHYS_VECTOR)
   return FALSE;
   }
 
-if (new == TRUE && type == GAMGI_PHYS_POLYGON &&
+if (new == TRUE && model == GAMGI_PHYS_POLYGON &&
 cache.new[STATIC_THICKNESS] == FALSE)
   {
   if (cache.local == TRUE)
@@ -1548,8 +1549,8 @@ plane->hkl[2] = hkl[2];
 plane->vectors = vectors;
 
 plane->order = order;
-plane->projection = projection;
-plane->type = type;
+plane->net = net;
+plane->model = model;
 
 plane->red = red;
 plane->green = green;
@@ -1591,10 +1592,10 @@ if (new == TRUE)
      * this is a crystallographic plane *
      ************************************/
 
-    if (cell->type == GAMGI_PHYS_PROJECTION)
+    if (cell->model == GAMGI_PHYS_PROJECTION)
       {
-      if (plane->type == GAMGI_PHYS_POLE) pole = TRUE; else pole = FALSE;
-      if (plane->type == GAMGI_PHYS_TRACE) trace = TRUE; else trace = FALSE;
+      if (plane->model == GAMGI_PHYS_POLE) pole = TRUE; else pole = FALSE;
+      if (plane->model == GAMGI_PHYS_TRACE) trace = TRUE; else trace = FALSE;
       gamgi_phys_plane_projection (plane, cell, pole, trace);
       }
     else
@@ -1617,10 +1618,10 @@ if (new == TRUE)
      * this is an atomic plane: 1) get list of parent atoms   *
      * 2) reorder list so the three defining atoms come first *
      *                                                        *
-     * the plane type is needed because of the rotation next  *
+     * the plane model is needed because of the rotation next *
      **********************************************************/
 
-    plane->type = GAMGI_PHYS_POLYGON;
+    plane->model = GAMGI_PHYS_POLYGON;
     plane->vectors = GAMGI_PHYS_PLANE_VECTORS;
 
     parent = gamgi_phys_plane_parent (cache.atom1, cache.atom2, cache.atom3, window);
@@ -1876,18 +1877,18 @@ if (class == GAMGI_ENGINE_PLANE)
     combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
     gtk_combo_box_set_active (GTK_COMBO_BOX (combo), plane->vectors - 1);
 
-    if (cell->type == GAMGI_PHYS_PROJECTION)
+    if (cell->model == GAMGI_PHYS_PROJECTION)
       {
       combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_net");
-      if (plane->projection == gamgi_phys_projection_wulff)
+      if (plane->net == gamgi_phys_projection_wulff)
         gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_WULFF);
-      if (plane->projection == gamgi_phys_projection_schmidt)
+      if (plane->net == gamgi_phys_projection_schmidt)
         gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_SCHMIDT);
 
       combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
-      if (plane->type == GAMGI_PHYS_POLE)
+      if (plane->model == GAMGI_PHYS_POLE)
         gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_POLE);
-      if (plane->type == GAMGI_PHYS_TRACE)
+      if (plane->model == GAMGI_PHYS_TRACE)
         gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_TRACE);
       }
     else
