@@ -17,9 +17,13 @@ static void static_clean (gamgi_window *window);
 
 static void static_reset (gamgi_window *window);
 
-static void static_global (GtkWidget *widget, void *data);
+static void static_list (GtkWidget *widget, void *data);
 
-static void static_apply (gamgi_text *text, gamgi_window *window);
+static void static_apply (gamgi_text *text, int scope, gamgi_window *window);
+
+static void static_ok_global (int scope, gamgi_window *window);
+
+static void static_ok_local (int scope, gamgi_window *window);
 
 static void static_ok (GtkWidget *widget, void *data);
 
