@@ -44,9 +44,11 @@
 #include "gamgi_gtk_text_select.h"
 #include "gamgi_gtk_text_modify.h"
 #include "gamgi_gtk_text_remove.h"
-#include "gamgi_gtk_orbital_create.h"
 #include "gamgi_gtk_orbital_copy.h"
+#include "gamgi_gtk_orbital_create.h"
 #include "gamgi_gtk_orbital_link.h"
+#include "gamgi_gtk_orbital_select.h"
+#include "gamgi_gtk_orbital_modify.h"
 #include "gamgi_gtk_orbital_remove.h"
 #include "gamgi_gtk_bond_config.h"
 #include "gamgi_gtk_bond_create.h"
@@ -96,6 +98,7 @@
 #include "gamgi_gtk_cluster_measure.h"
 #include "gamgi_gtk_cluster_remove.h"
 #include "gamgi_gtk_cell_create.h"
+#include "gamgi_gtk_cell_config.h"
 #include "gamgi_gtk_cell_copy.h"
 #include "gamgi_gtk_cell_select.h"
 #include "gamgi_gtk_cell_link.h"
@@ -281,10 +284,16 @@ gtk_widget_show (button);
 return button;
 }
 
-static void static_delete (GtkWidget *widget, 
+static int static_delete (GtkWidget *widget, 
 GdkEventButton *event, void *data)
 {
 gamgi_gtk_window_remove_confirm (widget, data);
+
+/*******************************
+ * TRUE: do not destroy window *
+ *******************************/
+
+return TRUE;
 }
 
 static void static_ok (GtkWidget *widget, void *data)
@@ -933,7 +942,7 @@ separator = gtk_menu_item_new ();
 gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
-static_item_insert (menu, "Config", "grey", NULL, window);
+static_item_insert (menu, "Config", NULL, gamgi_gtk_cell_config, window);
 
 /**********************
  * setup cluster menu *
@@ -1139,9 +1148,9 @@ g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_orbital_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_orbital_copy, window);
-static_item_insert (menu, "Select", "grey", gamgi_gtk_orbital_select, window);
+static_item_insert (menu, "Select", NULL, gamgi_gtk_orbital_select, window);
 static_item_insert (menu, "Link", NULL, gamgi_gtk_orbital_link, window);
-static_item_insert (menu, "Modify", "grey", gamgi_gtk_orbital_modify, window);
+static_item_insert (menu, "Modify", NULL, gamgi_gtk_orbital_modify, window);
 static_item_insert (menu, "Remove", NULL, gamgi_gtk_orbital_remove, window);
 
 separator = gtk_menu_item_new ();
