@@ -486,7 +486,6 @@ GtkWidget *frame;
 GtkWidget *treeview;
 GtkWidget *combo;
 GtkWidget *button;
-GtkWidget *entry;
 GtkWidget *label;
 GtkWidget *hbox_center, *hbox_left;
 GtkWidget *vbox_dialog, *vbox_page, *vbox_top, *vbox_top_top;
@@ -725,12 +724,13 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-g_object_set_data (G_OBJECT (dialog), "widget_min", entry);
-gtk_widget_show (entry);
+/**********************************************
+ * this widget will be removed in static_init *
+ **********************************************/
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "widget_min", combo);
 
 /*******
  * Max *
@@ -748,12 +748,13 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-g_object_set_data (G_OBJECT (dialog), "widget_max", entry);
-gtk_widget_show (entry);
+/**********************************************
+ * this widget will be removed in static_init *
+ **********************************************/
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "widget_max", combo);
 
 /*********************
  * Ok/Cancel buttons *
