@@ -25,6 +25,9 @@ static void static_method (GtkWidget *widget, void *data);
 
 static void static_reset (gamgi_window *window);
 
+static gamgi_dlist *static_ok_name (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window);
+
 static void static_ok (GtkWidget *widget, void *data);
 
 static void static_init (gamgi_window *window);
