@@ -261,7 +261,7 @@ int fileline, gamgi_window *window)
 char message[GAMGI_ENGINE_LINE];
 
 sprintf (message,
-"Invalid character data starting at line %d in file %s\n",
+"Invalid character data starting at line %d in file %s",
 fileline, filename);
 
 gamgi_gtk_dialog_message_create ("Error", message, window);
@@ -273,7 +273,7 @@ gamgi_bool gamgi_io_error_header (const char *identifier,
 char *filename, int fileline, gamgi_window *window)
 {
 char message[GAMGI_ENGINE_LINE];
-char shortname[GAMGI_ENGINE_LINE];
+char shortname[GAMGI_IO_SHORTNAME];
 
 /**************************************************
  * identifier is wrong, it could be anything.     *
