@@ -352,7 +352,6 @@ char filename[GAMGI_ENGINE_LINE];
 char hostname[GAMGI_ENGINE_LINE];
 char *body;
 gamgi_bool valid;
-int out;
 
 /*****************************
  * get hostname and filename *
@@ -362,6 +361,7 @@ fullname += strlen("http://");
 
 size = strcspn (fullname, "/");
 strcpy (filename, fullname + size);
+
 strncpy (hostname, fullname, size);
 hostname[size] = '\0';
 
@@ -379,7 +379,7 @@ if (fd < 0) return gamgi_io_error_open (shortname, window);
 sprintf (buffer, "GET %s HTTP/1.1\r\n" "Host: %s\r\n"
 "Pragma: no-cache\r\n" "Connection: close\r\n\r\n",
 filename, hostname);
-out = write (fd, buffer, strlen (buffer));
+write (fd, buffer, strlen (buffer));
 
 /**********************
  * handle HTTP header *
@@ -459,6 +459,7 @@ fullname += strlen("ftp://");
 
 size = strcspn (fullname, "/");
 strcpy (filename, fullname + size);
+
 strncpy (hostname, fullname, size);
 hostname[size] = '\0';
 
@@ -766,7 +767,6 @@ FILE *fp, int width, int height, gamgi_bool *error)
 {
 char auxname[2 * GAMGI_ENGINE_TOKEN];
 char command[2 * GAMGI_ENGINE_LINE];
-int out;
 
 /**********************************
  * 1) create fullname ppm file    *
@@ -783,7 +783,7 @@ sprintf (auxname, "gamgi%d", getpid ());
 
 sprintf (command, "(%s %s >%s; mv -f %s %s) &",
 GAMGI_IO_PNMTOPNG, fullname, auxname, auxname, fullname);
-out = system (command);
+system (command);
 
 return TRUE;
 }
@@ -793,7 +793,6 @@ FILE *fp, int width, int height, gamgi_bool *error)
 {
 char auxname[2 * GAMGI_ENGINE_TOKEN];
 char command[2 * GAMGI_ENGINE_LINE];
-int out;
 
 /**********************************
  * 1) create fullname ppm file    *
@@ -810,7 +809,7 @@ sprintf (auxname, "gamgi%d", getpid ());
 
 sprintf (command, "(%s %s >%s; mv -f %s %s) &",
 GAMGI_IO_PNMTOJPEG, fullname, auxname, auxname, fullname);
-out = system (command);
+system (command);
 
 return TRUE;
 }
@@ -820,7 +819,6 @@ FILE *fp, int width, int height, gamgi_bool *error)
 {
 char auxname[2 * GAMGI_ENGINE_TOKEN];
 char command[2 * GAMGI_ENGINE_LINE];
-int out;
 
 /**********************************
  * 1) create fullname ppm file    *
@@ -837,7 +835,7 @@ sprintf (auxname, "gamgi%d", getpid ());
 
 sprintf (command, "(%s -color %s >%s; mv -f %s %s) &",
 GAMGI_IO_PNMTOTIFF, fullname, auxname, auxname, fullname);
-out = system (command);
+system (command);
 
 return TRUE;
 }
