@@ -23,9 +23,9 @@
 #include "gamgi_mesa_bond.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_math_quaternion.h"
-#include "gamgi_io_x3d_render.h"
 #include "gamgi_io_file.h"
 #include "gamgi_io_error.h"
+#include "gamgi_io_x3d_render.h"
 
 /************* internal function ***********
  *                                         *
@@ -39,6 +39,15 @@ gamgi_bool *error)
 {
 char string[GAMGI_ENGINE_LINE];
 
+/*******************
+ * Transform start *
+ *******************/
+
+/*********************************************************
+ * move the object center to the origin, scale the       *
+ * object, move the object back to its original position *
+ *********************************************************/
+
 if (fabs (scale - 1.0) > GAMGI_MATH_TOLERANCE)
   {
   sprintf (string, "<Transform translation=\"%.*f %.*f %.*f\">\n",
@@ -70,6 +79,10 @@ if (fabs (scale - 1.0) > GAMGI_MATH_TOLERANCE)
 
 static void static_unscale (FILE *fp, double scale, gamgi_bool *error)
 {
+/*****************
+ * Transform end *
+ *****************/
+
 if (fabs (scale - 1.0) > GAMGI_MATH_TOLERANCE)
   gamgi_io_file_fprintf(fp, "</Transform>\n</Transform>\n</Transform>\n", error);
 }
@@ -79,8 +92,18 @@ double *start, double *end, int width, gamgi_bool *error)
 {
 char string[GAMGI_ENGINE_LINE];
 
+/***************
+ * Shape start *
+ ***************/
+
 gamgi_io_file_fprintf (fp, "<Shape>\n", error);
+
+/************************
+ * Appearance start+end *
+ ************************/
+
 gamgi_io_file_fprintf (fp, "<Appearance>\n", error);
+
 if (lights == TRUE)
   sprintf (string, "<Material diffuseColor=\"%.*f %.*f %.*f\"/>\n",
   GAMGI_MATH_DECIMAL_COLOR, color[0],
@@ -95,8 +118,13 @@ gamgi_io_file_fprintf (fp, string, error);
 
 sprintf (string, "<LineProperties linewidthScaleFactor=\"%d\"/>\n", width);
 gamgi_io_file_fprintf (fp, string, error);
+
 gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
 
+/******************
+ * Line start+end *
+ ******************/
+
 gamgi_io_file_fprintf (fp, "<IndexedLineSet coordIndex=\"0 1 -1\">\n", error);
 sprintf (string, "<Coordinate point=\"%.*f %.*f %.*f %.*f %.*f %.*f\"/>\n",
 gamgi->gamgi->length, start[0],
@@ -107,6 +135,11 @@ gamgi->gamgi->length, end[1],
 gamgi->gamgi->length, end[2]);
 gamgi_io_file_fprintf (fp, string, error);
 gamgi_io_file_fprintf (fp, "</IndexedLineSet>\n", error);
+
+/*************
+ * Shape end *
+ *************/
+
 gamgi_io_file_fprintf (fp, "</Shape>\n", error);
 }
 
@@ -115,8 +148,16 @@ double length, double radius, gamgi_bool *error)
 {
 char string[GAMGI_ENGINE_LINE];
 
+/***************
+ * Shape start *
+ ***************/
+
 gamgi_io_file_fprintf (fp, "<Shape>\n", error);
 
+/************************
+ * Appearance start+end *
+ ************************/
+
 gamgi_io_file_fprintf (fp, "<Appearance>\n", error);
 if (lights == TRUE)
   sprintf (string, "<Material shininess=\"%.*f\" diffuseColor=\"%.*f %.*f %.*f\"/>\n",
@@ -132,9 +173,18 @@ else
 gamgi_io_file_fprintf (fp, string, error);
 gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
 
+/**********************
+ * Cylinder start+end *
+ **********************/
+
 sprintf (string, "<Cylinder height=\"%.*f\" radius=\"%.*f\" top=\"false\" bottom=\"false\"/>\n",
 gamgi->gamgi->length, length, gamgi->gamgi->length, radius);
 gamgi_io_file_fprintf (fp, string, error);
+
+/*************
+ * Shape end *
+ *************/
+
 gamgi_io_file_fprintf (fp, "</Shape>\n", error);
 }
 
@@ -146,14 +196,17 @@ char string[GAMGI_ENGINE_LINE];
 double axis[3];
 double phi;
 
-/*********************************************
- * start scale, rotate, move Transform nodes *
- *********************************************/
+/*************************
+ * scale Transform start *
+ *************************/
 
 static_scale (fp, text->object.scale, text->center, error);
 
-gamgi_math_quaternion_to_axis (text->quaternion, &phi, axis);
+/*******************************
+ * rotate+move Transform start *
+ *******************************/
 
+gamgi_math_quaternion_to_axis (text->quaternion, &phi, axis);
 sprintf (string, "<Transform translation=\"%.*f %.*f %.*f\" rotation=\"%.*f %.*f %.*f %.*f\">\n",
 gamgi->gamgi->length, text->origin[0], 
 gamgi->gamgi->length, text->origin[1], 
@@ -163,12 +216,18 @@ gamgi->gamgi->length, axis[1],
 gamgi->gamgi->length, axis[2], 
 gamgi->gamgi->angle, phi);
 gamgi_io_file_fprintf (fp, string, error);
-	
-/*********************************
- * start Shape, Appearance nodes *
- *********************************/
 
-gamgi_io_file_fprintf (fp, "<Shape>\n<Appearance>\n", error);
+/***************
+ * Shape start *
+ ***************/
+
+gamgi_io_file_fprintf (fp, "<Shape>\n", error);
+
+/************************
+ * Appearance start+end *
+ ************************/
+
+gamgi_io_file_fprintf (fp, "<Appearance>\n", error);
 if (lights == TRUE)
   sprintf (string, "<Material diffuseColor=\"%.*f %.*f %.*f\"/>\n", 
   GAMGI_MATH_DECIMAL_COLOR, text->red, 
@@ -181,17 +240,22 @@ else
   GAMGI_MATH_DECIMAL_COLOR, text->blue);
 gamgi_io_file_fprintf(fp, string, error);
 gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
-	
+
+/*************************
+ * export geometric data *
+ *************************/
+
 if (text->font > GAMGI_IO_FONTS_WIRED)
   gamgi_io_x3d_render_solid (fp, text, error);
 else
   gamgi_io_x3d_render_wired (fp, text, error);
 	
-/******************************
- * end Shape, Transform nodes *
- ******************************/
+/************************************
+ * Shape, rotate+move Transform end *
+ ************************************/
 
-gamgi_io_file_fprintf (fp, "</Shape>\n</Transform>\n", error);
+gamgi_io_file_fprintf (fp, "</Shape>\n", error);
+gamgi_io_file_fprintf (fp, "</Transform>\n", error);
 
 /***********************
  * child objects: text *
@@ -200,6 +264,10 @@ gamgi_io_file_fprintf (fp, "</Shape>\n</Transform>\n", error);
 for (dlist = text->text_start; dlist != NULL; dlist = dlist->next)
   static_text (fp, GAMGI_CAST_TEXT dlist->data, lights, error);
 
+/***********************
+ * scale Transform end *
+ ***********************/
+
 static_unscale (fp, text->object.scale, error);
 }
 
@@ -207,6 +275,147 @@ static void static_orbital (FILE *fp, gamgi_orbital *orbital,
 gamgi_bool lights, gamgi_bool *error)
 {
 gamgi_dlist *dlist;
+int *dots;
+char string[GAMGI_ENGINE_LINE];
+double axis[3];
+double phi;
+float background[4];
+float color[3];
+
+/*************************
+ * scale Transform start *
+ *************************/
+
+static_scale (fp, orbital->object.scale, orbital->center, error);
+
+/*******************************
+ * rotate+move Transform start *
+ *******************************/
+
+gamgi_math_quaternion_to_axis (orbital->quaternion, &phi, axis);
+sprintf (string, "<Transform translation=\"%.*f %.*f %.*f\" rotation=\"%.*f %.*f %.*f %.*f\">\n",
+gamgi->gamgi->length, orbital->origin[0],
+gamgi->gamgi->length, orbital->origin[1],
+gamgi->gamgi->length, orbital->origin[2],
+gamgi->gamgi->length, axis[0],
+gamgi->gamgi->length, axis[1],
+gamgi->gamgi->length, axis[2],
+gamgi->gamgi->angle, phi);
+gamgi_io_file_fprintf (fp, string, error);
+
+glGetFloatv (GL_COLOR_CLEAR_VALUE, background);
+
+dots = orbital->dots;
+if (orbital->style == GAMGI_MESA_WIRED)
+  {
+  /*************************
+   * export geometric data *
+   *************************/
+
+  glLineWidth (4.0);
+  if (dots[1] > 0)
+    { 
+    color[0] = orbital->base_r;
+    color[1] = orbital->base_g;
+    color[2] = orbital->base_b;
+    gamgi_io_x3d_render_points (fp, dots[1],
+    orbital->points + 3 * dots[0], color, error);
+    }
+
+  if (dots[2] > 0)
+    {
+    color[0] = orbital->phase_r;
+    color[1] = orbital->phase_g;
+    color[2] = orbital->phase_b;
+    gamgi_io_x3d_render_points (fp, dots[2],
+    orbital->points + 3 * dots[0] + 3 * dots[1], color, error);
+    }
+  }
+
+if (orbital->style == GAMGI_MESA_SOLID)
+  {
+  if (dots[1] > 0)
+    {
+    /***************
+     * Shape start *
+     ***************/
+
+    /************************
+     * Appearance start+end *
+     ************************/
+
+    gamgi_io_file_fprintf (fp, "<Shape>\n", error);
+    gamgi_io_file_fprintf (fp, "<Appearance>\n", error);
+    if (lights == TRUE)
+      sprintf (string, "<Material diffuseColor=\"%.*f %.*f %.*f\"/>\n",
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_r,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_g,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_b);
+    else
+      sprintf (string, "<Material emissiveColor=\"%.*f %.*f %.*f\"/>\n",
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_r,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_g,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_b);
+    gamgi_io_file_fprintf (fp, string, error);
+    gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
+
+    /*************************
+     * export geometric data *
+     *************************/
+
+    gamgi_io_x3d_render_triangles (fp, dots[1] / 3,
+    orbital->points + 3 * dots[0], error);
+    gamgi_io_file_fprintf (fp, "</Shape>\n", error);
+
+    /*************
+     * Shape end *
+     *************/
+    }
+
+  if (dots[2] > 0)
+    {
+    /***************
+     * Shape start *
+     ***************/
+
+    /************************
+     * Appearance start+end *
+     ************************/
+
+    gamgi_io_file_fprintf (fp, "<Shape>\n", error);
+    gamgi_io_file_fprintf (fp, "<Appearance>\n", error);
+    if (lights == TRUE)
+      sprintf (string, "<Material diffuseColor=\"%.*f %.*f %.*f\"/>\n",
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_r,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_g,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_b);
+    else
+      sprintf (string, "<Material emissiveColor=\"%.*f %.*f %.*f\"/>\n",
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_r,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_g,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_b);
+    gamgi_io_file_fprintf (fp, string, error);
+    gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
+
+    /*************************
+     * export geometric data *
+     *************************/
+
+    gamgi_io_x3d_render_triangles (fp, dots[2] / 3,
+    orbital->points + 3 * dots[0] + 3 * dots[1], error);
+    gamgi_io_file_fprintf (fp, "</Shape>\n", error);
+
+    /*************
+     * Shape end *
+     *************/
+    }
+  }
+
+/*****************************
+ * rotate+move Transform end *
+ *****************************/
+
+gamgi_io_file_fprintf (fp, "</Transform>\n", error);
 
 /***********************
  * child objects: text *
@@ -214,6 +423,12 @@ gamgi_dlist *dlist;
 
 for (dlist = orbital->text_start; dlist!=NULL; dlist = dlist->next)
   static_text (fp, GAMGI_CAST_TEXT dlist->data, lights, error);
+
+/***********************
+ * scale Transform end *
+ ***********************/
+
+static_unscale (fp, orbital->object.scale, error);
 }
 
 static void static_bond (FILE *fp, gamgi_bond *bond, gamgi_atom *atom, 
@@ -518,7 +733,7 @@ static void static_direction (FILE *fp, gamgi_direction *direction,
 gamgi_bool lights, gamgi_bool *error)
 {
 gamgi_dlist * dlist;
-char string[256];
+char string[GAMGI_ENGINE_LINE];
 double axis[3];
 double phi;
 float color[3];
@@ -951,8 +1166,8 @@ if (cluster->loops != NULL)
 
   gamgi_io_file_fprintf (fp, "</Shape>\n", error);
 
-  if (cluster->n_dots > 0)
-    gamgi_io_x3d_render_points (fp, cluster->n_dots, 
+  if (cluster->atoms > 0)
+    gamgi_io_x3d_render_points (fp, cluster->atoms, 
     cluster->points, cluster->colors, error);
 
   gamgi_io_file_fprintf(fp, "</Transform>\n", error);
@@ -994,7 +1209,7 @@ static void static_cell (FILE *fp, gamgi_cell *cell,
 gamgi_bool lights, gamgi_bool *error)
 {
 gamgi_dlist * dlist;
-char string[256];
+char string[GAMGI_ENGINE_LINE];
 double axis[3];
 double phi;
 float background[4];
@@ -1056,7 +1271,7 @@ if (cell->loops != NULL && cell->borders != FALSE &&
   gamgi_io_file_fprintf (fp, string, error);
 		
   sprintf (string, "<LineProperties linewidthScaleFactor=\"%.*f\"/>\n", 
-  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_CELL_WIDTH);
+  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_CELL_LINE);
   gamgi_io_file_fprintf (fp, string, error);
   gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
 		
@@ -1088,7 +1303,7 @@ if (cell->lines != NULL)
   gamgi_io_file_fprintf (fp, string, error);
 
   sprintf (string, "<LineProperties linewidthScaleFactor=\"%.*f\"/>\n", 
-  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_CELL_WIDTH);
+  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_CELL_LINE);
   gamgi_io_file_fprintf (fp, string, error);
   gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
 
@@ -1340,7 +1555,7 @@ else
 gamgi_io_file_fprintf (fp, string, error);
 }
 
-static void static_layer (FILE * fp, gamgi_layer *layer, gamgi_bool *error)
+static void static_layer (FILE *fp, gamgi_layer *layer, gamgi_bool *error)
 {
 gamgi_dlist *dlist;
 char string[GAMGI_ENGINE_LINE];
@@ -1361,10 +1576,16 @@ gamgi_io_file_fprintf (fp, "<Scene>\n", error);
  *                                                             *
  * Possible values are: WALK, FLY, EXAMINE, LOOKAT, ANY, NONE  *
  * values can be combined, for example: type='"EXAMINE" "ANY"' *
+ *                                                             *
+ * Apparently, the GAMGI OpenGL lightning seems to be slightly *
+ * better simulated in X3D when global is set to false, which  *
+ * means that lights apply only to the local node.             *
  ***************************************************************/
 
-gamgi_io_file_fprintf (fp, "<NavigationInfo headlight=\"false\""
-" type=\"ANY\"/>\n", error);
+gamgi_io_file_fprintf (fp, "<NavigationInfo headlight=\"false\"", error);
+gamgi_io_file_fprintf (fp, " type='\"ANY\"'/>\n", error);
+
+gamgi_io_file_fprintf (fp, "<DirectionalLight global=\"false\"/>\n", error);
 
 /**************
  * projection *
@@ -1372,13 +1593,13 @@ gamgi_io_file_fprintf (fp, "<NavigationInfo headlight=\"false\""
 
 if (layer->perspective == TRUE)
   {
-  gamgi_io_file_fprintf (fp, "<Viewpoint description=\"gamgi\"", error);
-  sprintf (string, " fieldOfView=\"%.*f\"", 
+  gamgi_io_file_fprintf (fp, "<Viewpoint description=\"perspective\"", error);
+  sprintf (string, " fieldOfView=\"%.*f\"\n", 
   gamgi->gamgi->length, 2.0 * atan ((2.0 * layer->top) * 0.5 / layer->near));
   }
 else
   {
-  gamgi_io_file_fprintf (fp, "<OrthoViewpoint description=\"gamgi\"", error);
+  gamgi_io_file_fprintf (fp, "<OrthoViewpoint description=\"orthographic\"", error);
   sprintf (string, " fieldOfView=\"%.*f %.*f %.*f %.*f\"", 
   gamgi->gamgi->length, -layer->top, 
   gamgi->gamgi->length, -layer->top, 
@@ -1393,7 +1614,7 @@ gamgi_io_file_fprintf (fp, string, error);
 
 gamgi_math_vector_sub (layer->eye, layer->center, normal);
 gamgi_math_vector_normal (normal);
-sprintf (string, " orientation=\"%.*f %.*f %.*f %.*f\"", 
+sprintf (string, "orientation=\"%.*f %.*f %.*f %.*f\"", 
 gamgi->gamgi->length, normal[0], 
 gamgi->gamgi->length, normal[1], 
 gamgi->gamgi->length, normal[2],
