@@ -24,13 +24,13 @@ GAMGI_MATH_POLYTOPE_3, GAMGI_MATH_POLYTOPE_4 };
  * Converts radians to degrees *
  *******************************/
 
-#define GAMGI_MATH_RAD_DEG 360.0/(2*GAMGI_MATH_PI) 
+#define GAMGI_MATH_RAD_DEG (180.0/GAMGI_MATH_PI)
 
 /*******************************
  * Converts degrees to radians *
  *******************************/
 
-#define GAMGI_MATH_DEG_RAD (2*GAMGI_MATH_PI)/360.0 
+#define GAMGI_MATH_DEG_RAD (GAMGI_MATH_PI/180.0)
 
 /**************************************************
  * quaternions are rescaled after these rotations *
@@ -103,7 +103,6 @@ GAMGI_MATH_POLYTOPE_3, GAMGI_MATH_POLYTOPE_4 };
 #define GAMGI_MATH_DECIMAL_ANGLE       2
 #define GAMGI_MATH_DECIMAL_MASS        4
 #define GAMGI_MATH_DECIMAL_CHARGE      4
-#define GAMGI_MATH_DECIMAL_TEMPERATURE 2
 #define GAMGI_MATH_DECIMAL_OCCUPANCY   4
 #define GAMGI_MATH_DECIMAL_COLOR       3
 #define GAMGI_MATH_DECIMAL_SCALE       3
