@@ -287,7 +287,7 @@ double old;
  *        rotate yes, normalize yes           *
  **********************************************/
 
-if (direction->type == GAMGI_PHYS_LINE)
+if (direction->model == GAMGI_PHYS_LINE)
   {
   /**************************************
    *    a parent cell is not needed     *
@@ -355,7 +355,7 @@ double old;
  *     rotate yes, normalize yes       *
  ***************************************/
 
-if (plane->type == GAMGI_PHYS_POLYGON)
+if (plane->model == GAMGI_PHYS_POLYGON)
   {
   /******************************************************
    * polygon planes: 1) use transformed center to enter *
@@ -384,7 +384,7 @@ else
    * reciprocal space *
    ********************/
 
-  if (plane->type == GAMGI_PHYS_VECTOR)
+  if (plane->model == GAMGI_PHYS_VECTOR)
     {
     /********************
      * reciprocal space *
