@@ -33,6 +33,14 @@ void gamgi_math_position_text_translation_set (gamgi_text *text, double *origin)
 
 void gamgi_math_position_text_translation_get (gamgi_text *text, double *origin);
 
+void gamgi_math_position_orbital_rotation_set (gamgi_orbital *orbital, double *euler);
+
+void gamgi_math_position_orbital_rotation_get (gamgi_orbital *orbital, double *euler);
+
+void gamgi_math_position_orbital_translation_set (gamgi_orbital *orbital, double *origin);
+
+void gamgi_math_position_orbital_translation_get (gamgi_orbital *orbital, double *origin);
+
 void gamgi_math_position_direction_rotation_set (gamgi_direction *direction, 
 double *euler);
 
