@@ -27,7 +27,7 @@ double y, double z, double *x_2d, double *y_2d, double *z_2d);
 void gamgi_mesa_area_unproject (gamgi_window *window,
 int x_2d, int y_2d, double *x, double *y, double *z);
 
-unsigned char *gamgi_mesa_area_grab (int x,      
+unsigned char *gamgi_mesa_area_read (int x,      
 int y, int width, int height);
 
 gamgi_bool gamgi_mesa_area_configure (GtkWidget *widget, 
@@ -39,6 +39,9 @@ GdkEventExpose *event, void *data);
 gamgi_bool gamgi_mesa_area_press (GtkWidget *widget, 
 GdkEventButton *event, void *data);
 
+gamgi_bool gamgi_mesa_area_release (GtkWidget *widget,
+GdkEventButton *event, void *data);
+
 gamgi_bool gamgi_mesa_area_notify (GtkWidget *widget, 
 GdkEventMotion *event, void *data);
 
