@@ -13,21 +13,26 @@
  * internal functions *
  **********************
 
-static void static_sphere (double width);
+static void static_sphere (float size);
 
-static void static_axis (double *v, double width);
+static void static_axis (double *v, float size);
 
  **********************
  * external functions *
  **********************/
 
-void gamgi_mesa_axes (double *origin, double *a, double *b, double *c);
+void gamgi_mesa_axes (double *origin,
+double *a, double *b, double *c, float size);
 
-void gamgi_mesa_axes_color (double *origin, double *a, double *b, double *c);
+void gamgi_mesa_axes_color (double *origin,
+double *a, double *b, double *c, float size);
 
-void gamgi_mesa_axes_cell (gamgi_cell *cell, gamgi_bool color);
+void gamgi_mesa_axes_orbital (gamgi_orbital *orbital,
+gamgi_bool color, float size);
 
-void gamgi_mesa_axes_layer (gamgi_layer *layer, gamgi_bool color);
+void gamgi_mesa_axes_cell (gamgi_cell *cell, gamgi_bool color, float size);
+
+void gamgi_mesa_axes_layer (gamgi_layer *layer, gamgi_bool color, float size);
 
 /*************
  * Rationale *
