@@ -146,8 +146,8 @@ if (orbital->style == GAMGI_MESA_SOLID)
 
 if (orbital->frame == TRUE)
   gamgi_mesa_render_lines (orbital->lines, orbital->points);
-if (orbital->axes > 0.0)
-  gamgi_mesa_axes_orbital (orbital, FALSE);
+if (orbital->axes != GAMGI_CHEM_NONE)
+  gamgi_mesa_axes_orbital (orbital, FALSE, GAMGI_MESA_AXES_SIZE);
 
 glPopMatrix ();
 
@@ -826,8 +826,8 @@ else
       }
 
     gamgi_mesa_render_loops (cluster->loops, cluster->points);
-    if (cluster->n_dots > 0)
-      gamgi_mesa_render_points (cluster->n_dots, cluster->points);
+    if (cluster->atoms > 0)
+      gamgi_mesa_render_points (cluster->atoms, cluster->points);
 
     glDisable (GL_POLYGON_OFFSET_FILL);
     glLineWidth (1.0);
@@ -922,8 +922,8 @@ if (cell->model != GAMGI_PHYS_PROJECTION)
   glMultMatrixd (rotate);
   }
 
-glLineWidth (GAMGI_MESA_CELL_WIDTH);
-glPointSize (GAMGI_MESA_CELL_WIDTH);
+glLineWidth (gamgi->cell->borders_width);
+glPointSize (gamgi->cell->nodes_width);
 
 if (cell->faces == TRUE)
   {
@@ -941,7 +941,7 @@ if (cell->faces == TRUE)
 if (cell->lines != NULL)
   gamgi_mesa_render_lines (cell->lines, cell->points);
 
-if (cell->loops != NULL && cell->borders != FALSE &&
+if (cell->loops != NULL && cell->borders != GAMGI_PHYS_NONE &&
 (cell->lattice != GAMGI_PHYS_HEXAGONAL_P ||
 (cell->model != GAMGI_PHYS_WIGNER && cell->model != GAMGI_PHYS_CONVENTIONAL)) &&
 (cell->lattice != GAMGI_PHYS_ORTHORHOMBIC_C || cell->model != GAMGI_PHYS_WIGNER))
@@ -958,7 +958,8 @@ glPointSize (1.0);
  * draw axes *
  *************/
 
-if (cell->axes == TRUE) gamgi_mesa_axes_cell (cell, FALSE);
+if (cell->axes == TRUE)
+  gamgi_mesa_axes_cell (cell, FALSE, gamgi->cell->axes_size);
 
 glPopMatrix ();
 
@@ -1253,7 +1254,8 @@ glTranslatef (-layer->center[0], -layer->center[1], -layer->center[2]);
  * draw axes *
  *************/
 
-if (layer->axes == TRUE) gamgi_mesa_axes_layer (layer, FALSE);
+if (layer->axes == TRUE)
+  gamgi_mesa_axes_layer (layer, FALSE, GAMGI_MESA_AXES_SIZE);
 
 dlist = layer->text_start;
 while (dlist != NULL)
