@@ -600,13 +600,13 @@ switch (object->class)
 
   case GAMGI_ENGINE_DIRECTION:
   direction = GAMGI_CAST_DIRECTION object;
-  if (direction->type == GAMGI_PHYS_LINE)
+  if (direction->model == GAMGI_PHYS_LINE)
     gamgi_mesa_rotate_direction (GAMGI_CAST_DIRECTION object, quaternion, rotate, center);
   break;
 
   case GAMGI_ENGINE_PLANE:
   plane = GAMGI_CAST_PLANE object;
-  if (plane->type == GAMGI_PHYS_POLYGON)
+  if (plane->model == GAMGI_PHYS_POLYGON)
     gamgi_mesa_rotate_plane (GAMGI_CAST_PLANE object, quaternion, rotate, center);
   break;
 
@@ -753,7 +753,7 @@ double quaternion[4];
 for (dlist = gamgi->directions; dlist != NULL; dlist = dlist->next)
   { 
   direction = GAMGI_CAST_DIRECTION dlist->data;
-  if (direction->type != GAMGI_PHYS_LINE) continue;
+  if (direction->model != GAMGI_PHYS_LINE) continue;
 
   static_layer (GAMGI_CAST_OBJECT direction,
   &layer, angle, axis, quaternion, rotate);
@@ -772,7 +772,7 @@ double quaternion[4];
 for (dlist = gamgi->planes; dlist != NULL; dlist = dlist->next)
   {
   plane = GAMGI_CAST_PLANE dlist->data;
-  if (plane->type != GAMGI_PHYS_POLYGON) continue;
+  if (plane->model != GAMGI_PHYS_POLYGON) continue;
 
   static_layer (GAMGI_CAST_OBJECT plane,
   &layer, angle, axis, quaternion, rotate);
