@@ -13,13 +13,23 @@
  * external functions *
  **********************/
 
-void gamgi_mesa_scale_object (gamgi_object *object, double scale);
+void gamgi_mesa_scale_default (gamgi_object *object, double scale);
 
 void gamgi_mesa_scale_light (gamgi_light *light, double scale);
 
 void gamgi_mesa_scale_window (gamgi_window *window, double scale);
 
-void gamgi_mesa_scale_object_list (gamgi_dlist *start, double scale);
+void gamgi_mesa_scale_object (gamgi_object *object, double scale);
+
+void gamgi_mesa_scale_default_list (gamgi_dlist *start, double scale);
+
+void gamgi_mesa_scale_text_list (double scale);
+
+void gamgi_mesa_scale_group_list (double scale);
+
+void gamgi_mesa_scale_cluster_list (double scale);
+
+void gamgi_mesa_scale_assembly_list (double scale);
 
 void gamgi_mesa_scale_light_list (double scale);
 
