@@ -68,6 +68,7 @@ orbital->seed = GAMGI_MATH_SEED;
 
 orbital->phase = TRUE;
 orbital->frame = TRUE;
+orbital->axes = GAMGI_CHEM_NONE;
 for (i = 0; i < 8; i++)
   orbital->octants[i] = TRUE;
 
@@ -175,7 +176,7 @@ plane->blue = plane_class->blue;
 void gamgi_mesa_start_group (gamgi_group *group, gamgi_group_class *group_class)
 {
 strcpy (group->object.name, "Group");
-group->type = GAMGI_CHEM_CONTAINER;
+group->reference = GAMGI_CHEM_CONTAINER;
 
 group->red = GAMGI_MESA_GROUP_R;
 group->green = GAMGI_MESA_GROUP_G;
@@ -207,7 +208,7 @@ strcpy (molecule->object.name, "Molecule");
 void gamgi_mesa_start_cluster (gamgi_cluster *cluster, gamgi_cluster_class *cluster_class)
 {
 strcpy (cluster->object.name, "Cluster");
-cluster->type = GAMGI_CHEM_CONTAINER;
+cluster->reference = GAMGI_CHEM_CONTAINER;
 }
 
 /***** external function *****
@@ -222,12 +223,16 @@ void gamgi_mesa_start_cell (gamgi_cell *cell, gamgi_cell_class *cell_class)
 {
 strcpy (cell->object.name, "Cell");
 
-cell->origin_vectors = GAMGI_PHYS_CELL_VECTORS_ORIGIN;
-cell->axes_vectors = GAMGI_PHYS_CELL_VECTORS_AXES;
+cell->model = cell_class->model;
+cell->axes = cell_class->axes;
 
-cell->red = GAMGI_MESA_CELL_R;
-cell->green = GAMGI_MESA_CELL_G;
-cell->blue = GAMGI_MESA_CELL_B;
+cell->borders = cell_class->borders;
+cell->faces = cell_class->faces;
+cell->nodes = cell_class->nodes;
+
+cell->red = cell_class->red;
+cell->green = cell_class->green;
+cell->blue = cell_class->blue;
 }
 
 /****** external function *****
