@@ -839,6 +839,40 @@ if (extruded->open == TRUE) gluTessEndContour (extruded->tesselator);
 gluTessEndPolygon (extruded->tesselator);
 }
 
+gamgi_bool static static_glyph (FT_Face face, gamgi_extruded *extruded,
+int ascii, FT_Glyph *glyph, char *error)
+{
+int index;
+
+/***********************
+ * load TrueType glyph *
+ ***********************/
+
+index = FT_Get_Char_Index (face, ascii);
+if (index == 0)
+  {
+  if (error != NULL)
+    sprintf (error, "Unable to get index for glyph %c", ascii);
+  return FALSE;
+  }
+
+if (FT_Load_Glyph (face, index, FT_LOAD_NO_SCALE) != 0)
+  {
+  if (error != NULL)
+    sprintf (error, "Unable to load glyph %c", ascii);
+  return FALSE;
+  }
+
+if (FT_Get_Glyph (face->glyph, glyph) != 0)
+  {
+  if (error != NULL)
+    sprintf (error, "Unable to get glyph %c", ascii);
+  return FALSE;
+  }
+
+return TRUE;
+}
+
 static gamgi_bool static_compile_wired (const float *points,
 const int *driver, int c)
 {
@@ -867,37 +901,20 @@ return TRUE;
 }
 
 static gamgi_bool static_compile_solid (FT_Face face,
-gamgi_extruded *extruded, int c)
+gamgi_extruded *extruded, int c, char *error)
 {
 gamgi_slist *slist;
 FT_OutlineGlyph glyph;
 double depth;
-int ascii, index = 0;
+int ascii;
 
 /***********************
  * load TrueType glyph *
  ***********************/
 
 ascii = c + GAMGI_IO_ASCII_START;
-
-index = FT_Get_Char_Index (face, ascii);
-if (index == 0)
-  {
-  printf ("Could not get index for glyph %c.\n", ascii);
+if (static_glyph (face, extruded, ascii, (void *) &glyph, error) == FALSE)
   return FALSE;
-  }
-
-if (FT_Load_Glyph (face, index, FT_LOAD_NO_SCALE) != 0)
-  {
-  printf ("Could not load glyph %c.\n", ascii);
-  return FALSE;
-  }
-
-if (FT_Get_Glyph (face->glyph, (FT_Glyph *) (void *) &glyph) != 0)
-  {
-  printf ("Could not get glyph %c.\n", ascii);
-  return FALSE;
-  }
 
 /**************************************************************
  * In theory, TrueType contours are defined clockwise and     *
@@ -1004,7 +1021,7 @@ return TRUE;
 
 static gamgi_bool static_compile (gamgi_enum font, 
 const float *points, const int *driver, FT_Face face, 
-gamgi_extruded *extruded, int c)
+gamgi_extruded *extruded, int c, char *error)
 {
 gamgi_bool valid;
 
@@ -1021,7 +1038,7 @@ glNewList (font * GAMGI_IO_ASCII_RANGE + c, GL_COMPILE);
 if (font <= GAMGI_IO_FONTS_WIRED)
   valid = static_compile_wired (points, driver, c);
 else
-  valid = static_compile_solid (face, extruded, c);
+  valid = static_compile_solid (face, extruded, c, error);
 
 /*******************
  * end OpenGL list *
@@ -1050,19 +1067,19 @@ return valid;
  * The source format of outlines is a collection of closed paths  *
  * called contours. Each contour delimits an outer or inner       *
  * region of the glyph, and can be made of either line segments   *
- * or Bzier arcs.                                                *
+ * or Bezier arcs.                                                *
  *                                                                *
  * The arcs are defined through control points, and can be either *
- * second-order (these are conic Bziers) or third-order (cubic   *
- * Bziers) polynomials, depending on the font format. Note that  *
- * conic Bziers are usually called quadratic Bziers in the      *
+ * second-order (these are conic Beziers) or third-order (cubic   *
+ * Beziers) polynomials, depending on the font format. Note that  *
+ * conic Beziers are usually called quadratic Beziers in the      *
  * literature. Hence, each point of the outline has an associated *
  * flag indicating its type (normal or control point). And        *
  * scaling the points will scale the whole outline.               *
  ******************************************************************/
 
 static gamgi_extruded *static_extruded_create (gamgi_enum font,
-FT_Library *freetype, FT_Face *face)
+FT_Library *freetype, FT_Face *face, char *error)
 {
 gamgi_extruded *extruded;
 char fullname[GAMGI_IO_FULLNAME];
@@ -1080,7 +1097,8 @@ gamgi_mesa_text_data_solid (font, filename);
 
 if (gamgi->text->path == NULL)
   {
-  printf ("Could not get font path\n");
+  if (error != NULL)
+    sprintf (error, "Unable to get font location");
   return NULL;
   }
 
@@ -1090,7 +1108,8 @@ if (gamgi->text->path == NULL)
 
 if (strlen (gamgi->text->path) + strlen (filename) + 2 > GAMGI_IO_FULLNAME)
   {
-  printf ("Could not handle filename\n");
+  if (error != NULL)
+    sprintf (error, "Unable to handle font filename");
   return NULL;
   }
 
@@ -1107,13 +1126,15 @@ sprintf (fullname, "%s/%s", gamgi->text->path, filename);
 
 if (FT_Init_FreeType (freetype) != 0)
   {
-  printf ("Could not open the library.\n");
+  if (error != NULL)
+    sprintf (error, "Unable to open the FreeType library");
   return NULL;
   }
 
 if (FT_New_Face (*freetype, fullname, 0, face) != 0)
   {
-  printf ("Could not open the font.\n");
+  if (error != NULL)
+    sprintf (error, "Unable to open the font file %s", filename);
   FT_Done_FreeType (*freetype);
   return NULL;
   }
@@ -1227,7 +1248,7 @@ return extruded;
 }
 
 static gamgi_bool static_extruded_remove (FT_Library freetype,
-FT_Face face, gamgi_extruded *extruded)
+FT_Face face, gamgi_extruded *extruded, char *error)
 {
 gamgi_bool valid = TRUE;
 
@@ -1251,13 +1272,15 @@ free (extruded);
 
 if (FT_Done_Face (face) != 0)
   {
-  printf ("Could not close the font.\n");
+  if (error != NULL)
+    sprintf (error, "Unable to close the font");
   valid = FALSE;
   }
 
 if (FT_Done_FreeType (freetype) != 0)
   {
-  printf ("Could not close the library.\n");
+  if (error != NULL)
+    sprintf (error, "Unable to close the FreeType library");
   valid = FALSE;
   }
 
@@ -1266,7 +1289,7 @@ return valid;
 
 static gamgi_bool static_start (gamgi_enum font,
 const float **points, const int **driver, FT_Library *freetype, 
-FT_Face *face, gamgi_extruded **extruded)
+FT_Face *face, gamgi_extruded **extruded, char *error)
 {
 if (font > GAMGI_IO_FONTS_WIRED)
   {
@@ -1274,7 +1297,7 @@ if (font > GAMGI_IO_FONTS_WIRED)
    * solid font: get font filename and create resources *
    ******************************************************/
 
-  *extruded = static_extruded_create (font, freetype, face);
+  *extruded = static_extruded_create (font, freetype, face, error);
   if (*extruded == NULL) return FALSE;
   }
 else
@@ -1289,8 +1312,8 @@ else
 return TRUE;
 }
 
-static gamgi_bool static_end (gamgi_enum font,
-FT_Library freetype, FT_Face face, gamgi_extruded *extruded)
+static gamgi_bool static_end (gamgi_enum font, FT_Library freetype,
+FT_Face face, gamgi_extruded *extruded, char *error)
 {
 if (font > GAMGI_IO_FONTS_WIRED)
   {
@@ -1298,15 +1321,15 @@ if (font > GAMGI_IO_FONTS_WIRED)
    * solid font: free resources *
    ******************************/
 
-  return static_extruded_remove (freetype, face, extruded);
+  return static_extruded_remove (freetype, face, extruded, error);
   }
 
 return TRUE;
 }
 
-static gamgi_bool static_create (gamgi_enum font, 
-int ascii, int **glyphs, int *n_glyphs, const float *points, 
-const int *driver, FT_Face face, gamgi_extruded *extruded)
+static gamgi_bool static_create (gamgi_enum font, int ascii,
+int *n_glyphs, int **glyphs, const float *points, const int *driver,
+FT_Face face, gamgi_extruded *extruded, char *error)
 {
 int c = ascii - GAMGI_IO_ASCII_START;
 
@@ -1321,13 +1344,13 @@ n_glyphs[font - 1]++;
 glyphs[font - 1][c]++;
 if (glyphs[font - 1][c] == 1)
   if (static_compile (font, points, driver, 
-  face, extruded, c) == FALSE) return FALSE;
+  face, extruded, c, error) == FALSE) return FALSE;
 
 return TRUE;
 }
 
 static void static_remove (gamgi_enum font, 
-int ascii, int **glyphs, int *n_glyphs)
+int ascii, int *n_glyphs, int **glyphs)
 {
 int c = ascii - GAMGI_IO_ASCII_START;
 
@@ -1360,7 +1383,7 @@ int i;
  ****************************************************/
 
 for (i = 0; i < length; i++)
-  static_remove (font, string[i], glyphs, n_glyphs);
+  static_remove (font, string[i], n_glyphs, glyphs);
 
 if (n_glyphs[font - 1] == 0)
   gamgi_mesa_text_font_remove (font, glyphs);
@@ -1433,10 +1456,9 @@ return TRUE;
 }
 
 static gamgi_bool static_center_solid (char *string, int length,
-FT_Face face, gamgi_extruded *extruded, double *center)
+FT_Face face, gamgi_extruded *extruded, double *center, char *error)
 {
 FT_Glyph glyph;
-int index = 0;
 int i, ascii;
 double width;
 double offset;
@@ -1449,30 +1471,13 @@ offset = 0.0;
 gamgi_math_vector_zero (center);
 for (i = 0; i < length; i++)
   {
-  ascii = (int) string[i];
-  
   /***********************
    * load TrueType glyph *
    ***********************/
 
-  index = FT_Get_Char_Index (face, ascii);
-  if (index == 0)
-    {
-    printf ("Could not get index for glyph %c.\n", ascii);
+  ascii = (int) string[i];
+  if (static_glyph (face, extruded, ascii, &glyph, error) == FALSE)
     return FALSE;
-    }
-
-  if (FT_Load_Glyph (face, index, FT_LOAD_NO_SCALE) != 0)
-    {
-    printf ("Could not load glyph %c.\n", ascii);
-    return FALSE;
-    }
-
-  if (FT_Get_Glyph (face->glyph, &glyph) != 0)
-    {
-    printf ("Could not get glyph %c.\n", ascii);
-    return FALSE;
-    }
 
   /**************************************
    * sum the centers for all characters *
@@ -1511,7 +1516,16 @@ gamgi_math_vector_scale (center, center, extruded->scale);
 return TRUE;
 }
 
-gamgi_bool gamgi_mesa_text_font_increase (gamgi_text *text)
+static gamgi_bool static_font_remove (gamgi_enum font,
+int *n_glyphs, int **glyphs)
+{
+if (n_glyphs[font - 1] == 0)
+  gamgi_mesa_text_font_remove (font, glyphs);
+
+return FALSE;
+}
+
+gamgi_bool gamgi_mesa_text_font_increase (gamgi_text *text, char *error)
 {
 int **glyphs = gamgi->glyphs;
 int *n_glyphs = gamgi->n_glyphs;
@@ -1534,9 +1548,9 @@ int i;
 
 if (text->font == 0) return TRUE;
 
-/**********************************
+/************************************
  * create glyphs array if necessary *
- **********************************/
+ ************************************/
 
 if (n_glyphs[text->font - 1] == 0)
   gamgi_mesa_text_font_create (text->font, glyphs);
@@ -1554,8 +1568,9 @@ new = static_new (text->font, text->string, text->length, glyphs);
  * start resources only if there are new glyphs *
  ************************************************/
 
-if (new == TRUE && static_start (text->font, &points, &driver, 
-&freetype, &face, &extruded) == FALSE) return FALSE;
+if (new == TRUE && static_start (text->font, &points,
+&driver, &freetype, &face, &extruded, error) == FALSE)
+  return static_font_remove (text->font, n_glyphs, glyphs);
 
 /**************************************************
  * create characters, one each time, or remove    *
@@ -1565,20 +1580,21 @@ if (new == TRUE && static_start (text->font, &points, &driver,
  **************************************************/
 
 for (i = 0; i < text->length; i++)
-  if (static_create (text->font, text->string[i], glyphs, 
-  n_glyphs, points, driver, face, extruded) == FALSE)
+  if (static_create (text->font, text->string[i], n_glyphs,
+  glyphs, points, driver, face, extruded, error) == FALSE)
     {
     static_decrease (text->font, text->string, i); 
-    static_end (text->font, freetype, face, extruded);
-    return FALSE;
+    static_end (text->font, freetype, face, extruded, error);
+    return static_font_remove (text->font, n_glyphs, glyphs);
     }
 
 /**********************************************
  * end resources only if there are new glyphs *
  **********************************************/
 
-if (new == TRUE && static_end (text->font, freetype, 
-face, extruded) == FALSE) return FALSE;
+if (new == TRUE && static_end (text->font,
+freetype, face, extruded, error) == FALSE)
+  return static_font_remove (text->font, n_glyphs, glyphs);
 
 return TRUE;
 }
@@ -1596,7 +1612,7 @@ static_decrease (text->font, text->string, text->length);
 }
 
 gamgi_bool gamgi_mesa_text_center (gamgi_enum font,
-char *string, int length, double *center)
+char *string, int length, double *center, char *error)
 {
 gamgi_extruded *extruded = NULL;
 const float *points = NULL;
@@ -1609,7 +1625,8 @@ gamgi_bool valid;
  * start resources *
  *******************/
 
-valid = static_start (font, &points, &driver, &freetype, &face, &extruded);
+valid = static_start (font, &points,
+&driver, &freetype, &face, &extruded, error);
 
 /*************************
  * determine text center *
@@ -1618,7 +1635,7 @@ valid = static_start (font, &points, &driver, &freetype, &face, &extruded);
 if (valid == TRUE)
   {
   if (font > GAMGI_IO_FONTS_WIRED)
-    valid = static_center_solid (string, length, face, extruded, center);
+    valid = static_center_solid (string, length, face, extruded, center, error);
   else
     valid = static_center_wired (string, length, points, center);
   }
@@ -1628,7 +1645,7 @@ if (valid == TRUE)
  *****************/
 
 if (extruded != NULL)
-  static_end (font, freetype, face, extruded);
+  static_end (font, freetype, face, extruded, error);
 
 return valid;
 }
