@@ -88,6 +88,16 @@ GAMGI_PHYS_111, GAMGI_PHYS_122, GAMGI_PHYS_211 };
 #define GAMGI_PHYS_CELL_O2 0
 #define GAMGI_PHYS_CELL_O3 0
 
+/*******************************************************
+ * default for cell model, axes, borders, faces, nodes *
+ *******************************************************/
+
+#define GAMGI_PHYS_CELL_MODEL   GAMGI_PHYS_CONVENTIONAL
+#define GAMGI_PHYS_CELL_AXES    FALSE
+#define GAMGI_PHYS_CELL_BORDERS GAMGI_PHYS_ALL
+#define GAMGI_PHYS_CELL_FACES   FALSE
+#define GAMGI_PHYS_CELL_NODES   TRUE
+
 /*******************************
  * default Wyckoff coordinates *
  *******************************/
