@@ -455,7 +455,7 @@ return inside;
 }
 
 static void static_projection (gamgi_direction *direction,
-gamgi_cell *cell, gamgi_enum type)
+gamgi_cell *cell, gamgi_enum model)
 {
 gamgi_direction *direction_new;
 
@@ -478,9 +478,9 @@ else
 if (strcmp (direction->object.name, "") == 0)
   gamgi_phys_direction_name (direction->uvw[0], direction->uvw[1],
   direction->uvw[2], direction_new->object.name);
-direction_new->type = type;
+direction_new->model = model;
 
-gamgi_phys_projection_create (direction_new->type, &direction_new->points,
+gamgi_phys_projection_create (direction_new->model, &direction_new->points,
 &direction_new->n_points, &direction_new->loops, &direction_new->n_loops);
 
 gamgi_engine_link_direction_cell (direction_new, cell);
@@ -630,8 +630,11 @@ int uvw[3];
 
 /***********************************************************
  * get uvw direction indices in terms of primitive vectors *
+ *                                                         *
+ * the initialization is only to avoid a compiler warning  *
  ***********************************************************/
 
+uvw[0] = uvw[1] = uvw[2] = 0;
 if (direction->vectors == GAMGI_PHYS_PRIMITIVE)
   {
   uvw[0] = direction->uvw[0];
@@ -720,7 +723,7 @@ gamgi_bool inside = TRUE;
  * direction representation *
  ****************************/
 
-direction->type = GAMGI_PHYS_LINE;
+direction->model = GAMGI_PHYS_LINE;
 
 /********************************************
  * get 2 points describing the direction:   *
@@ -756,7 +759,7 @@ cell->p1, cell->p2, cell->p3, translate);
 gamgi_math_vector_add (r1, translate, r1);
 gamgi_math_vector_add (r2, translate, r2);
 
-if (cell->type == GAMGI_PHYS_SPHERE)
+if (cell->model == GAMGI_PHYS_SPHERE)
   {
   /************************************************
    * get an array of points describing the        *
@@ -1018,7 +1021,7 @@ double zero[3], normal[3], translation[3];
  * direction representation *
  ****************************/
 
-direction->type = GAMGI_PHYS_LINE;
+direction->model = GAMGI_PHYS_LINE;
 
 /**********************************************************************
  * initially the parent object is rotated and translated backward so  *
@@ -1109,7 +1112,7 @@ gamgi_engine_link_object_object (GAMGI_CAST_OBJECT direction, parent);
 strcpy (direction->object.name, "Direction");
 
 direction->reference = GAMGI_ENGINE_ATOM;
-direction->type = GAMGI_PHYS_LINE;
+direction->model = GAMGI_PHYS_LINE;
 
 direction->red = red;
 direction->green = green;
