@@ -69,7 +69,7 @@ gamgi_phys_reciprocal_points (plane);
  * plane representation *
  ************************/
 
-plane->type = GAMGI_PHYS_VECTOR;
+plane->model = GAMGI_PHYS_VECTOR;
 
 gamgi_engine_link_plane_cell (plane, cell);
 }
@@ -81,7 +81,7 @@ double u[3], v[3], translate[3];
 int n, h, k, l;
 gamgi_enum vectors;
 
-if (cell->type == GAMGI_PHYS_CONVENTIONAL)
+if (cell->model == GAMGI_PHYS_CONVENTIONAL)
   vectors = GAMGI_PHYS_CONVENTIONAL;
 else
   vectors = GAMGI_PHYS_PRIMITIVE;
@@ -550,7 +550,7 @@ int n;
 
 index = (int *) malloc (cell->n_nodes * 3 * sizeof (int));
 
-switch (cell->type)
+switch (cell->model)
   {
   case GAMGI_PHYS_CONVENTIONAL:
   switch (cell->lattice)
@@ -628,7 +628,7 @@ gamgi_enum o4;
  * primitive lattices OR primitive volumes *
  *******************************************/
 
-if (cell->type != GAMGI_PHYS_CONVENTIONAL ||
+if (cell->model != GAMGI_PHYS_CONVENTIONAL ||
 gamgi_phys_cell_primitive (cell->lattice) == cell->lattice)
   { 
   offset[0] = cell->o1;
@@ -1045,7 +1045,7 @@ return inside;
 }
 
 static void static_projection (gamgi_plane *plane,
-gamgi_cell *cell, gamgi_enum type)
+gamgi_cell *cell, gamgi_enum model)
 {
 gamgi_plane *plane_new;
 
@@ -1068,9 +1068,9 @@ else
 if (strcmp (plane->object.name, "") == 0)
   gamgi_phys_plane_name (plane->hkl[0], plane->hkl[1],
   plane->hkl[2], plane_new->object.name);
-plane_new->type = type;
+plane_new->model = model;
 
-gamgi_phys_projection_create (plane_new->type, &plane_new->points,
+gamgi_phys_projection_create (plane_new->model, &plane_new->points,
 &plane_new->n_points, &plane_new->loops, &plane_new->n_loops);
 
 gamgi_engine_link_plane_cell (plane_new, cell);
@@ -1408,7 +1408,7 @@ gamgi_bool inside = TRUE;
  * plane representation *
  ************************/
 
-plane->type = GAMGI_PHYS_POLYGON;
+plane->model = GAMGI_PHYS_POLYGON;
 
 /*******************************************
  * get 3 points describing the plane: they *
@@ -1444,7 +1444,7 @@ gamgi_math_vector_add (r1, translate, r1);
 gamgi_math_vector_add (r2, translate, r2);
 gamgi_math_vector_add (r3, translate, r3);
 
-if (cell->type == GAMGI_PHYS_SPHERE)
+if (cell->model == GAMGI_PHYS_SPHERE)
   {
   /********************************************
    * get an array of points describing the    *
@@ -1606,7 +1606,7 @@ double zero[3], normal[3], translation[3];
  * plane representation *
  ************************/
 
-plane->type = GAMGI_PHYS_POLYGON;
+plane->model = GAMGI_PHYS_POLYGON;
 
 /********************************************************************
  * initially the parent object is rotated and translated backward   *
@@ -1704,7 +1704,7 @@ gamgi_engine_link_object_object (GAMGI_CAST_OBJECT plane, parent);
 strcpy (plane->object.name, "Plane");
 
 plane->reference = GAMGI_ENGINE_ATOM;
-plane->type = GAMGI_PHYS_POLYGON;
+plane->model = GAMGI_PHYS_POLYGON;
 
 plane->red = red;
 plane->green = green;
