@@ -15,7 +15,7 @@
 
 gamgi_enum gamgi_phys_reciprocal_lattice (gamgi_enum lattice);
 
-void gamgi_phys_reciprocal_vectors (double factor, double *p1, 
+void gamgi_phys_reciprocal_vectors (double reciprocal, double *p1, 
 double *p2, double *p3, double *b1, double *b2, double *b3);
 
 /**********************
@@ -26,7 +26,7 @@ static void static_cell_copy (gamgi_cell *cell_old, gamgi_cell *cell);
 
 static void static_cell_increase (gamgi_enum lattice, gamgi_cell *cell);
 
-static void static_vectors (double factor, gamgi_enum lattice,
+static void static_vectors (double reciprocal, gamgi_enum lattice,
 double *p1, double *p2, double *p3, double *b1, double *b2, double *b3);
 
 static void static_lattice (gamgi_cell *cell, double *rotate);
@@ -38,6 +38,8 @@ gamgi_cell *cell, double *rotate);
  * external functions *
  **********************/
 
+void gamgi_phys_reciprocal_points (gamgi_plane *plane);
+
 gamgi_cell *gamgi_phys_reciprocal_primitive (gamgi_cell *cell_old,
 double factor, gamgi_window *window);
 
